import copy
import datetime
from typing import Any, Dict, Iterator, List, Literal, Optional, Union

from lseg_analytics.core.common._resource_base import (
    AsyncPollingResponse,
    AsyncRequestResponse,
    ResourceBase,
)
from lseg_analytics.core.exceptions import (
    LibraryException,
    ResourceNotFound,
    check_async_polling_response,
    check_async_request_response,
    check_exception_and_raise,
    check_id,
)

from lseg_analytics.pricing._basic_client.models import (
    AdjustableDate,
    AmortizationDefinition,
    AmortizationTypeEnum,
    Amount,
    BachelierParameters,
    BasePricingParameters,
    BlackScholesEquityParameters,
    BlackScholesFxParameters,
    BlackScholesInterestRateFuture,
    BusinessDayAdjustmentDefinition,
    CapFloorDefinition,
    CapFloorTypeEnum,
    Cashflow,
    CmdtyOptionVolSurfaceChoice,
    CmdtyVolSurfaceInput,
    CompoundingModeEnum,
    ConvexityAdjustment,
    CouponReferenceDateEnum,
    CreditCurveChoice,
    CreditCurveInput,
    CurveDataPoint,
    Date,
    DatedRate,
    DatedValue,
    DateMovingConvention,
    DayCountBasis,
    Description,
    DirectionEnum,
    Dividend,
    DividendTypeEnum,
    EndOfMonthConvention,
    EqOptionVolSurfaceChoice,
    EqVolSurfaceInput,
    FixedRateDefinition,
    FloatingRateDefinition,
    FrequencyEnum,
    FutureDate,
    FutureDateCalculationMethodEnum,
    FxCurveInput,
    FxForwardCurveChoice,
    FxOptionVolSurfaceChoice,
    FxPricingParameters,
    FxRateTypeEnum,
    FxVolSurfaceInput,
    HestonEquityParameters,
    IncomeTaxCashflow,
    IndexCompoundingDefinition,
    IndexFixing,
    IndexFixingForwardSourceEnum,
    IndexObservationMethodEnum,
    InnerError,
    InterestCashflow,
    InterestRateDefinition,
    InterestRateLegDefinition,
    InterestRateTypeEnum,
    IrCapVolSurfaceChoice,
    IrCurveChoice,
    IrMeasure,
    IrPricingParameters,
    IrRiskFields,
    IrSwapInstrumentRiskFields,
    IrSwapInstrumentValuationFields,
    IrSwapSolvingParameters,
    IrSwapSolvingTarget,
    IrSwapSolvingVariable,
    IrSwaptionVolCubeChoice,
    IrValuationFields,
    IrVolCubeInput,
    IrVolSurfaceInput,
    IrZcCurveInput,
    LoanAsCollectionItem,
    LoanDefinition,
    LoanDefinitionInstrument,
    LoanInstrumentDescriptionFields,
    LoanInstrumentRiskFields,
    LoanInstrumentSolveResponseFieldsOnResourceResponseData,
    LoanInstrumentSolveResponseFieldsResponseData,
    LoanInstrumentSolveResponseFieldsResponseWithError,
    LoanInstrumentValuationFields,
    LoanInstrumentValuationResponseFieldsOnResourceResponseData,
    LoanInstrumentValuationResponseFieldsResponseData,
    LoanInstrumentValuationResponseFieldsResponseWithError,
    Location,
    MarketData,
    MarketVolatility,
    Measure,
    ModelParameters,
    MonthEnum,
    NumericalMethodEnum,
    OffsetDefinition,
    OptionPricingParameters,
    OptionSolvingParameters,
    OptionSolvingTarget,
    OptionSolvingVariable,
    OptionSolvingVariableEnum,
    PartyEnum,
    PaymentOccurrenceEnum,
    PayoffCashflow,
    PremiumCashflow,
    PriceSideWithLastEnum,
    PrincipalCashflow,
    PrincipalDefinition,
    Rate,
    ReferenceDate,
    RelativeAdjustableDate,
    ResetDatesDefinition,
    ScheduleDefinition,
    ServiceError,
    SettlementCashflow,
    SolvingLegEnum,
    SolvingMethod,
    SolvingMethodEnum,
    SolvingResult,
    SortingOrderEnum,
    Spot,
    SpreadCompoundingModeEnum,
    StepRateDefinition,
    StrikeTypeEnum,
    StubIndexReferences,
    StubRuleEnum,
    SwapSolvingVariableEnum,
    TimeStampEnum,
    UnitEnum,
    VolatilityTypeEnum,
    VolCubePoint,
    VolModelTypeEnum,
    VolSurfacePoint,
    ZcTypeEnum,
)
from lseg_analytics.pricing._client.client import Client

from ._loan import Loan
from ._logger import logger

__all__ = [
    "AmortizationDefinition",
    "AmortizationTypeEnum",
    "Amount",
    "BachelierParameters",
    "BasePricingParameters",
    "BlackScholesEquityParameters",
    "BlackScholesFxParameters",
    "BlackScholesInterestRateFuture",
    "BusinessDayAdjustmentDefinition",
    "CapFloorDefinition",
    "CapFloorTypeEnum",
    "Cashflow",
    "CmdtyOptionVolSurfaceChoice",
    "CmdtyVolSurfaceInput",
    "CompoundingModeEnum",
    "ConvexityAdjustment",
    "CouponReferenceDateEnum",
    "CreditCurveChoice",
    "CreditCurveInput",
    "CurveDataPoint",
    "DatedRate",
    "DatedValue",
    "DirectionEnum",
    "Dividend",
    "DividendTypeEnum",
    "EqOptionVolSurfaceChoice",
    "EqVolSurfaceInput",
    "FixedRateDefinition",
    "FloatingRateDefinition",
    "FutureDate",
    "FutureDateCalculationMethodEnum",
    "FxCurveInput",
    "FxForwardCurveChoice",
    "FxOptionVolSurfaceChoice",
    "FxPricingParameters",
    "FxRateTypeEnum",
    "FxVolSurfaceInput",
    "HestonEquityParameters",
    "IncomeTaxCashflow",
    "IndexCompoundingDefinition",
    "IndexFixing",
    "IndexFixingForwardSourceEnum",
    "IndexObservationMethodEnum",
    "InterestCashflow",
    "InterestRateDefinition",
    "InterestRateLegDefinition",
    "InterestRateTypeEnum",
    "IrCapVolSurfaceChoice",
    "IrCurveChoice",
    "IrMeasure",
    "IrPricingParameters",
    "IrRiskFields",
    "IrSwapInstrumentRiskFields",
    "IrSwapInstrumentValuationFields",
    "IrSwapSolvingParameters",
    "IrSwapSolvingTarget",
    "IrSwapSolvingVariable",
    "IrSwaptionVolCubeChoice",
    "IrValuationFields",
    "IrVolCubeInput",
    "IrVolSurfaceInput",
    "IrZcCurveInput",
    "Loan",
    "LoanAsCollectionItem",
    "LoanDefinition",
    "LoanDefinitionInstrument",
    "LoanInstrumentDescriptionFields",
    "LoanInstrumentRiskFields",
    "LoanInstrumentSolveResponseFieldsOnResourceResponseData",
    "LoanInstrumentSolveResponseFieldsResponseData",
    "LoanInstrumentSolveResponseFieldsResponseWithError",
    "LoanInstrumentValuationFields",
    "LoanInstrumentValuationResponseFieldsOnResourceResponseData",
    "LoanInstrumentValuationResponseFieldsResponseData",
    "LoanInstrumentValuationResponseFieldsResponseWithError",
    "MarketData",
    "MarketVolatility",
    "Measure",
    "ModelParameters",
    "MonthEnum",
    "NumericalMethodEnum",
    "OffsetDefinition",
    "OptionPricingParameters",
    "OptionSolvingParameters",
    "OptionSolvingTarget",
    "OptionSolvingVariable",
    "OptionSolvingVariableEnum",
    "PartyEnum",
    "PaymentOccurrenceEnum",
    "PayoffCashflow",
    "PremiumCashflow",
    "PriceSideWithLastEnum",
    "PrincipalCashflow",
    "PrincipalDefinition",
    "Rate",
    "ResetDatesDefinition",
    "ScheduleDefinition",
    "SettlementCashflow",
    "SolvingLegEnum",
    "SolvingMethod",
    "SolvingMethodEnum",
    "SolvingResult",
    "Spot",
    "SpreadCompoundingModeEnum",
    "StepRateDefinition",
    "StrikeTypeEnum",
    "StubIndexReferences",
    "SwapSolvingVariableEnum",
    "TimeStampEnum",
    "UnitEnum",
    "VolCubePoint",
    "VolModelTypeEnum",
    "VolSurfacePoint",
    "VolatilityTypeEnum",
    "ZcTypeEnum",
    "delete",
    "load",
    "price",
    "search",
    "value",
]


def load(
    *,
    resource_id: Optional[str] = None,
    name: Optional[str] = None,
    space: Optional[str] = None,
):
    """
    Load a Loan using its name and space

    Parameters
    ----------
    resource_id : str, optional
        The Loan id. Or the combination of the space and name of the resource with a slash, e.g. 'HOME/my_resource'.
        Required if name is not provided.
    name : str, optional
        The Loan name.
        Required if resource_id is not provided. The name parameter must be specified when the object is first created. Thereafter it is optional.
    space : str, optional
        The space where the Loan is stored. Space is like a namespace where resources are stored. By default there are two spaces:
        LSEG is reserved for LSEG maintained resources, HOME is reserved for user's default space. If space is not specified, HOME will be used.

    Returns
    -------
    Loan
        The Loan instance.

    Examples
    --------
    >>> # execute the search of loan templates using id
    >>> loaded_template = load(resource_id=loan_templates[0].id)
    >>>
    >>> print(loaded_template)
    <Loan space='HOME' name='TestLoan1750953126327056' 1b7dd5de‥>

    """
    if not isinstance(resource_id, (str, type(None))):
        raise TypeError(f"Expected resource_id as a string, got {resource_id!r}")
    if resource_id:
        if name or space:
            logger.warn("resource_id argument received, name & space arguments are ignored")
        return _load_by_id(resource_id)
    if not name:
        raise ValueError("Either resource_id or name argument should be provided")
    logger.info(f"Load Loan {name} from space={space!r}")
    spaces = [space] if space else None
    result = search(names=[name], spaces=spaces)
    if not result:
        logger.error(f"Loan {name} not found in space={space!r}")
        raise ResourceNotFound(f"Resource Loan not found by identifier name={name} space={space}")
    elif not isinstance(result, list):
        raise LibraryException(f"Expected list of results, got {result}")
    elif len(result) > 1:
        logger.warn(f"Found more than one result for name={name!r} and space={space!r}, returning the first one")
    return _load_by_id(result[0].id)


def delete(
    *,
    resource_id: Optional[str] = None,
    name: Optional[str] = None,
    space: Optional[str] = None,
):
    """
    Delete Loan instance from the server.

    Parameters
    ----------
    resource_id : str, optional
        The Loan resource ID.
        Required if name is not provided.
    name : str, optional
        The Loan name.
        Required if resource_id is not provided.
    space : str, optional
        The space where the Loan is stored. Space is like a namespace where resources are stored. By default there are two spaces:
        LSEG is reserved for LSEG maintained resources, HOME is reserved for user's default space. If space is not specified, HOME will be used.

    Returns
    -------
    ServiceErrorResponse, optional
        Error response, if applicable, otherwise None

    Examples
    --------
    >>> # Delete cloned template
    >>> delete(resource_id=cloned_template.id)
    True

    """
    if not isinstance(resource_id, (str, type(None))):
        raise TypeError(f"Expected resource_id as a string, got {resource_id!r}")
    if resource_id:
        if name or space:
            logger.warn("resource_id argument received, name & space arguments are ignored")
        return _delete_by_id(resource_id)
    if not name:
        raise ValueError("Either resource_id or name argument should be provided")
    logger.info(f"Delete Loan {name} from space={space!r}")
    spaces = [space] if space else None
    result = search(names=[name], spaces=spaces)
    if not result:
        logger.error(f"Loan {name} not found in space={space!r}")
        raise ResourceNotFound(f"Resource Loan not found by identifier name={name} space={space}")
    elif not isinstance(result, list):
        raise LibraryException(f"Expected list of results, got {result}")
    return _delete_by_id(result[0].id)


def _delete_by_id(instrument_id: str) -> bool:
    """
    Delete a Loan that exists in the platform. The Loan can be identified either by its unique ID (GUID format) or by its location path (space/name).

    Parameters
    ----------
    instrument_id : str
        The instrument identifier.

    Returns
    --------
    bool


    Examples
    --------


    """

    try:
        logger.info(f"Deleting Loan with id: {instrument_id}")
        Client().loan_resource.delete(instrument_id=instrument_id)
        logger.info(f"Deleted Loan with id: {instrument_id}")

        return True
    except Exception as err:
        logger.error(f"Error deleting Loan with id: {instrument_id}")
        check_exception_and_raise(err, logger)


def _load_by_id(instrument_id: str, fields: Optional[str] = None) -> Loan:
    """
    Access a Loan existing in the platform (read). The Loan can be identified either by its unique ID (GUID format) or by its location path (space/name).

    Parameters
    ----------
    instrument_id : str
        The instrument identifier.
    fields : str, optional
        A parameter used to select the fields to return in response. If not provided, all fields will be returned.
        Some usage examples:
        1. Simply enumerating the fields, separating them by ',', e.g. 'fields=//please insert the selected fields here, e.g., field1, field2 //'
        2. Using parentheses to indicate nesting, e.g. 'fields= //please insert the selected field and subfields here, e.g., field1(subfield1, subfield2), field2(subfield3)//’
        3. Using forward slash '/' to indicate nesting, e.g. 'fields=//please insert the selected field and subfields here, e.g.,  field1/subfield1, field1/subfield2, field2/subfield3//’ (same result as example above)
        4. Operators can even be combined (forward slashes in brackets, not the way around), e.g. 'fields=//please insert the selected field and subfields here, e.g.,  field1(subfield1/subsubfield1), field2/subfield2//'

    Returns
    --------
    Loan


    Examples
    --------


    """

    try:
        logger.info(f"Opening Loan with id: {instrument_id}")

        response = Client().loan_resource.read(instrument_id=instrument_id, fields=fields)

        output = Loan(response.data.definition, response.data.description)

        output._id = response.data.id

        output._location = response.data.location

        return output
    except Exception as err:
        logger.error("Error opening Loan:")
        check_exception_and_raise(err, logger)


def price(
    *,
    definitions: List[LoanDefinitionInstrument],
    pricing_preferences: Optional[IrPricingParameters] = None,
    market_data: Optional[MarketData] = None,
    return_market_data: Optional[bool] = None,
    fields: Optional[str] = None,
) -> LoanInstrumentSolveResponseFieldsResponseData:
    """
    Calculate the price (i.e., their respective fixed rates) of loans provided in the request so that a chosen property (e.g., market value, duration) equals a target value.

    Parameters
    ----------
    definitions : List[LoanDefinitionInstrument]
        An array of objects describing a curve or an instrument.
        Please provide either a full definition (for a user-defined curve/instrument), or reference to a curve/instrument definition saved in the platform, or the code identifying the existing curve/instrument.
    pricing_preferences : IrPricingParameters, optional
        The parameters that control the computation of the analytics.
    market_data : MarketData, optional
        The market data used to compute the analytics.
    return_market_data : bool, optional
        Boolean property to determine if undelying market data used for calculation should be returned in the response
    fields : str, optional
        A parameter used to select the fields to return in response. If not provided, all fields will be returned.
        Some usage examples:
        1. Simply enumerating the fields, separating them by ',', e.g. 'fields=//please insert the selected fields here, e.g., field1, field2 //'
        2. Using parentheses to indicate nesting, e.g. 'fields= //please insert the selected field and subfields here, e.g., field1(subfield1, subfield2), field2(subfield3)//’
        3. Using forward slash '/' to indicate nesting, e.g. 'fields=//please insert the selected field and subfields here, e.g.,  field1/subfield1, field1/subfield2, field2/subfield3//’ (same result as example above)
        4. Operators can even be combined (forward slashes in brackets, not the way around), e.g. 'fields=//please insert the selected field and subfields here, e.g.,  field1(subfield1/subsubfield1), field2/subfield2//'

    Returns
    --------
    LoanInstrumentSolveResponseFieldsResponseData


    Examples
    --------
    >>> business_day_adj = BusinessDayAdjustmentDefinition(calendars= [] , convention= "ModifiedFollowing")
    >>> start = AdjustableDate(date= "2021-03-02")
    >>> end =  RelativeAdjustableDate( reference_date= "StartDate", tenor= "10Y")
    >>> rate_definition = FloatingRateDefinition(index= "LSEG/EUR_ESTR_ON_FTSE")
    >>> interest_periods = ScheduleDefinition(business_day_adjustment= business_day_adj, start_date= start , end_date= end,frequency= "Annual", roll_convention= "Same")
    >>> offset_def = OffsetDefinition( business_day_adjustment= business_day_adj, direction= "Backward", reference_date= "PeriodEndDate", tenor= "0D" )
    >>> principal_definition = PrincipalDefinition( amount= 1000000, currency= "EUR")
    >>> loan_definition  = LoanDefinition(rate=rate_definition, interest_periods= interest_periods, payment_offset= offset_def, coupon_day_count= 'Dcb_Actual_360', accrual_day_count= 'Dcb_Actual_360', principal= principal_definition, payer= 'Party2', receiver= 'Party1')


    >>> loan_definition_Instrument = LoanDefinitionInstrument(definition=loan_definition)
    >>> pricing_parameters = IrPricingParameters( valuation_date= '2021-03-02')


    >>> price_result = price(definitions= [loan_definition_Instrument], pricing_preferences= pricing_parameters)
    >>> print(price_result)
    {'pricingPreferences': {'valuationDate': '2021-03-02', 'reportCurrency': 'EUR'}, 'analytics': [{'description': {'instrumentTag': '', 'instrumentDescription': 'Receive EUR Annual +0bp ESTR', 'startDate': '2021-03-02', 'endDate': '2031-03-03', 'tenor': '10Y'}, 'valuation': {'accrued': {'value': 0.0, 'percent': 0.0, 'dealCurrency': {'value': 0.0, 'currency': 'EUR'}, 'reportCurrency': {'value': 0.0, 'currency': 'EUR'}}, 'marketValue': {'value': -18572.358113432358, 'dealCurrency': {'value': -18572.358113432358, 'currency': 'EUR'}, 'reportCurrency': {'value': -18572.358113432358, 'currency': 'EUR'}}, 'cleanMarketValue': {'value': -18572.358113432358, 'dealCurrency': {'value': -18572.358113432358, 'currency': 'EUR'}, 'reportCurrency': {'value': -18572.358113432358, 'currency': 'EUR'}}}, 'risk': {'duration': {'value': 1.0}, 'modifiedDuration': {'value': -6.501023075545686e-05}, 'benchmarkHedgeNotional': {'value': 0.0, 'currency': 'EUR'}, 'annuity': {'value': 0.0, 'dealCurrency': {'value': 0.0, 'currency': 'EUR'}, 'reportCurrency': {'value': 0.0, 'currency': 'EUR'}}, 'dv01': {'value': -0.006501023075543344, 'bp': -6.501023075543344e-05, 'dealCurrency': {'value': -0.006501023075543344, 'currency': 'EUR'}, 'reportCurrency': {'value': -0.006501023075543344, 'currency': 'EUR'}}, 'pv01': {'value': -1020.7340782749961, 'bp': -10.207340782749963, 'dealCurrency': {'value': -1020.7340782749961, 'currency': 'EUR'}, 'reportCurrency': {'value': -1020.7340782749961, 'currency': 'EUR'}}, 'br01': {'value': 0.0, 'dealCurrency': {'value': 0.0, 'currency': 'EUR'}, 'reportCurrency': {'value': 0.0, 'currency': 'EUR'}}}, 'cashflows': [{'paymentType': 'Interest', 'annualRate': {'value': -0.5776998687611, 'unit': 'Percentage'}, 'discountFactor': 1.0058917441089001, 'startDate': '2021-03-02', 'endDate': '2022-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.5857234780388354, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2021-03-03', 'accrualStartDate': '2021-03-02', 'couponRate': {'value': -0.565, 'unit': 'Percentage'}, 'fixingDate': '2021-03-02', 'forwardSource': 'Fixing', 'referenceRate': {'value': -0.565, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-04', 'accrualStartDate': '2021-03-03', 'couponRate': {'value': -0.5638247, 'unit': 'Percentage'}, 'fixingDate': '2021-03-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5638247, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-05', 'accrualStartDate': '2021-03-04', 'couponRate': {'value': -0.56269014, 'unit': 'Percentage'}, 'fixingDate': '2021-03-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56269014, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-08', 'accrualStartDate': '2021-03-05', 'couponRate': {'value': -0.5615541, 'unit': 'Percentage'}, 'fixingDate': '2021-03-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5615541, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-09', 'accrualStartDate': '2021-03-08', 'couponRate': {'value': -0.56157726, 'unit': 'Percentage'}, 'fixingDate': '2021-03-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56157726, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-10', 'accrualStartDate': '2021-03-09', 'couponRate': {'value': -0.56215525, 'unit': 'Percentage'}, 'fixingDate': '2021-03-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56215525, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-11', 'accrualStartDate': '2021-03-10', 'couponRate': {'value': -0.5630757, 'unit': 'Percentage'}, 'fixingDate': '2021-03-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5630757, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-12', 'accrualStartDate': '2021-03-11', 'couponRate': {'value': -0.5642472, 'unit': 'Percentage'}, 'fixingDate': '2021-03-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5642472, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-15', 'accrualStartDate': '2021-03-12', 'couponRate': {'value': -0.56607765, 'unit': 'Percentage'}, 'fixingDate': '2021-03-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56607765, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-16', 'accrualStartDate': '2021-03-15', 'couponRate': {'value': -0.56723964, 'unit': 'Percentage'}, 'fixingDate': '2021-03-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56723964, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-17', 'accrualStartDate': '2021-03-16', 'couponRate': {'value': -0.5674731, 'unit': 'Percentage'}, 'fixingDate': '2021-03-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5674731, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-18', 'accrualStartDate': '2021-03-17', 'couponRate': {'value': -0.5675007, 'unit': 'Percentage'}, 'fixingDate': '2021-03-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5675007, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-19', 'accrualStartDate': '2021-03-18', 'couponRate': {'value': -0.5673635, 'unit': 'Percentage'}, 'fixingDate': '2021-03-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5673635, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-22', 'accrualStartDate': '2021-03-19', 'couponRate': {'value': -0.5671325, 'unit': 'Percentage'}, 'fixingDate': '2021-03-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5671325, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-23', 'accrualStartDate': '2021-03-22', 'couponRate': {'value': -0.5670536, 'unit': 'Percentage'}, 'fixingDate': '2021-03-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5670536, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-24', 'accrualStartDate': '2021-03-23', 'couponRate': {'value': -0.56707686, 'unit': 'Percentage'}, 'fixingDate': '2021-03-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56707686, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-25', 'accrualStartDate': '2021-03-24', 'couponRate': {'value': -0.56714046, 'unit': 'Percentage'}, 'fixingDate': '2021-03-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56714046, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-26', 'accrualStartDate': '2021-03-25', 'couponRate': {'value': -0.5672355, 'unit': 'Percentage'}, 'fixingDate': '2021-03-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5672355, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-29', 'accrualStartDate': '2021-03-26', 'couponRate': {'value': -0.56739277, 'unit': 'Percentage'}, 'fixingDate': '2021-03-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56739277, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-30', 'accrualStartDate': '2021-03-29', 'couponRate': {'value': -0.5675264, 'unit': 'Percentage'}, 'fixingDate': '2021-03-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5675264, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-31', 'accrualStartDate': '2021-03-30', 'couponRate': {'value': -0.56756794, 'unit': 'Percentage'}, 'fixingDate': '2021-03-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56756794, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-01', 'accrualStartDate': '2021-03-31', 'couponRate': {'value': -0.5675971, 'unit': 'Percentage'}, 'fixingDate': '2021-03-31', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5675971, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-06', 'accrualStartDate': '2021-04-01', 'couponRate': {'value': -0.56757945, 'unit': 'Percentage'}, 'fixingDate': '2021-04-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56757945, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-07', 'accrualStartDate': '2021-04-06', 'couponRate': {'value': -0.5675136, 'unit': 'Percentage'}, 'fixingDate': '2021-04-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5675136, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-08', 'accrualStartDate': '2021-04-07', 'couponRate': {'value': -0.5674745, 'unit': 'Percentage'}, 'fixingDate': '2021-04-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5674745, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-09', 'accrualStartDate': '2021-04-08', 'couponRate': {'value': -0.5674419, 'unit': 'Percentage'}, 'fixingDate': '2021-04-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5674419, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-12', 'accrualStartDate': '2021-04-09', 'couponRate': {'value': -0.56738925, 'unit': 'Percentage'}, 'fixingDate': '2021-04-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56738925, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-13', 'accrualStartDate': '2021-04-12', 'couponRate': {'value': -0.5673761, 'unit': 'Percentage'}, 'fixingDate': '2021-04-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5673761, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-14', 'accrualStartDate': '2021-04-13', 'couponRate': {'value': -0.5673758, 'unit': 'Percentage'}, 'fixingDate': '2021-04-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5673758, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-15', 'accrualStartDate': '2021-04-14', 'couponRate': {'value': -0.567382, 'unit': 'Percentage'}, 'fixingDate': '2021-04-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.567382, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-16', 'accrualStartDate': '2021-04-15', 'couponRate': {'value': -0.5673947, 'unit': 'Percentage'}, 'fixingDate': '2021-04-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5673947, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-19', 'accrualStartDate': '2021-04-16', 'couponRate': {'value': -0.5674326, 'unit': 'Percentage'}, 'fixingDate': '2021-04-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5674326, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-20', 'accrualStartDate': '2021-04-19', 'couponRate': {'value': -0.56751, 'unit': 'Percentage'}, 'fixingDate': '2021-04-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56751, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-21', 'accrualStartDate': '2021-04-20', 'couponRate': {'value': -0.567555, 'unit': 'Percentage'}, 'fixingDate': '2021-04-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.567555, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-22', 'accrualStartDate': '2021-04-21', 'couponRate': {'value': -0.5676065, 'unit': 'Percentage'}, 'fixingDate': '2021-04-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5676065, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-23', 'accrualStartDate': '2021-04-22', 'couponRate': {'value': -0.56766444, 'unit': 'Percentage'}, 'fixingDate': '2021-04-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56766444, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-26', 'accrualStartDate': '2021-04-23', 'couponRate': {'value': -0.5677929, 'unit': 'Percentage'}, 'fixingDate': '2021-04-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5677929, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-27', 'accrualStartDate': '2021-04-26', 'couponRate': {'value': -0.5679608, 'unit': 'Percentage'}, 'fixingDate': '2021-04-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5679608, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-28', 'accrualStartDate': '2021-04-27', 'couponRate': {'value': -0.5680511, 'unit': 'Percentage'}, 'fixingDate': '2021-04-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5680511, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-29', 'accrualStartDate': '2021-04-28', 'couponRate': {'value': -0.5681478, 'unit': 'Percentage'}, 'fixingDate': '2021-04-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5681478, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-30', 'accrualStartDate': '2021-04-29', 'couponRate': {'value': -0.568251, 'unit': 'Percentage'}, 'fixingDate': '2021-04-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.568251, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-03', 'accrualStartDate': '2021-04-30', 'couponRate': {'value': -0.56846994, 'unit': 'Percentage'}, 'fixingDate': '2021-04-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56846994, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-04', 'accrualStartDate': '2021-05-03', 'couponRate': {'value': -0.5687284, 'unit': 'Percentage'}, 'fixingDate': '2021-05-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5687284, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-05', 'accrualStartDate': '2021-05-04', 'couponRate': {'value': -0.5688622, 'unit': 'Percentage'}, 'fixingDate': '2021-05-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5688622, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-06', 'accrualStartDate': '2021-05-05', 'couponRate': {'value': -0.5689943, 'unit': 'Percentage'}, 'fixingDate': '2021-05-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5689943, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-07', 'accrualStartDate': '2021-05-06', 'couponRate': {'value': -0.56912297, 'unit': 'Percentage'}, 'fixingDate': '2021-05-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56912297, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-10', 'accrualStartDate': '2021-05-07', 'couponRate': {'value': -0.56935996, 'unit': 'Percentage'}, 'fixingDate': '2021-05-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56935996, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-11', 'accrualStartDate': '2021-05-10', 'couponRate': {'value': -0.56960356, 'unit': 'Percentage'}, 'fixingDate': '2021-05-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56960356, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-12', 'accrualStartDate': '2021-05-11', 'couponRate': {'value': -0.5697152, 'unit': 'Percentage'}, 'fixingDate': '2021-05-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5697152, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-13', 'accrualStartDate': '2021-05-12', 'couponRate': {'value': -0.5698234, 'unit': 'Percentage'}, 'fixingDate': '2021-05-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5698234, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-14', 'accrualStartDate': '2021-05-13', 'couponRate': {'value': -0.56992817, 'unit': 'Percentage'}, 'fixingDate': '2021-05-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56992817, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-17', 'accrualStartDate': '2021-05-14', 'couponRate': {'value': -0.5701174, 'unit': 'Percentage'}, 'fixingDate': '2021-05-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5701174, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-18', 'accrualStartDate': '2021-05-17', 'couponRate': {'value': -0.5703133, 'unit': 'Percentage'}, 'fixingDate': '2021-05-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5703133, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-19', 'accrualStartDate': '2021-05-18', 'couponRate': {'value': -0.5704011, 'unit': 'Percentage'}, 'fixingDate': '2021-05-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5704011, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-20', 'accrualStartDate': '2021-05-19', 'couponRate': {'value': -0.5704854, 'unit': 'Percentage'}, 'fixingDate': '2021-05-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5704854, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-21', 'accrualStartDate': '2021-05-20', 'couponRate': {'value': -0.5705663, 'unit': 'Percentage'}, 'fixingDate': '2021-05-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5705663, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-24', 'accrualStartDate': '2021-05-21', 'couponRate': {'value': -0.5707078, 'unit': 'Percentage'}, 'fixingDate': '2021-05-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5707078, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-25', 'accrualStartDate': '2021-05-24', 'couponRate': {'value': -0.570856, 'unit': 'Percentage'}, 'fixingDate': '2021-05-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.570856, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-26', 'accrualStartDate': '2021-05-25', 'couponRate': {'value': -0.5709199, 'unit': 'Percentage'}, 'fixingDate': '2021-05-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5709199, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-27', 'accrualStartDate': '2021-05-26', 'couponRate': {'value': -0.57098037, 'unit': 'Percentage'}, 'fixingDate': '2021-05-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57098037, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-28', 'accrualStartDate': '2021-05-27', 'couponRate': {'value': -0.5710375, 'unit': 'Percentage'}, 'fixingDate': '2021-05-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5710375, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-31', 'accrualStartDate': '2021-05-28', 'couponRate': {'value': -0.57113117, 'unit': 'Percentage'}, 'fixingDate': '2021-05-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57113117, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-01', 'accrualStartDate': '2021-05-31', 'couponRate': {'value': -0.5712317, 'unit': 'Percentage'}, 'fixingDate': '2021-05-31', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5712317, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-02', 'accrualStartDate': '2021-06-01', 'couponRate': {'value': -0.5712718, 'unit': 'Percentage'}, 'fixingDate': '2021-06-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5712718, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-03', 'accrualStartDate': '2021-06-02', 'couponRate': {'value': -0.5713084, 'unit': 'Percentage'}, 'fixingDate': '2021-06-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5713084, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-04', 'accrualStartDate': '2021-06-03', 'couponRate': {'value': -0.57134163, 'unit': 'Percentage'}, 'fixingDate': '2021-06-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57134163, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-07', 'accrualStartDate': '2021-06-04', 'couponRate': {'value': -0.5713929, 'unit': 'Percentage'}, 'fixingDate': '2021-06-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5713929, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-08', 'accrualStartDate': '2021-06-07', 'couponRate': {'value': -0.5714619, 'unit': 'Percentage'}, 'fixingDate': '2021-06-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5714619, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-09', 'accrualStartDate': '2021-06-08', 'couponRate': {'value': -0.571492, 'unit': 'Percentage'}, 'fixingDate': '2021-06-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.571492, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-10', 'accrualStartDate': '2021-06-09', 'couponRate': {'value': -0.5715222, 'unit': 'Percentage'}, 'fixingDate': '2021-06-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5715222, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-11', 'accrualStartDate': '2021-06-10', 'couponRate': {'value': -0.5715524, 'unit': 'Percentage'}, 'fixingDate': '2021-06-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5715524, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-14', 'accrualStartDate': '2021-06-11', 'couponRate': {'value': -0.57160395, 'unit': 'Percentage'}, 'fixingDate': '2021-06-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57160395, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-15', 'accrualStartDate': '2021-06-14', 'couponRate': {'value': -0.57167387, 'unit': 'Percentage'}, 'fixingDate': '2021-06-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57167387, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-16', 'accrualStartDate': '2021-06-15', 'couponRate': {'value': -0.57170445, 'unit': 'Percentage'}, 'fixingDate': '2021-06-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57170445, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-17', 'accrualStartDate': '2021-06-16', 'couponRate': {'value': -0.571735, 'unit': 'Percentage'}, 'fixingDate': '2021-06-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.571735, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-18', 'accrualStartDate': '2021-06-17', 'couponRate': {'value': -0.5717657, 'unit': 'Percentage'}, 'fixingDate': '2021-06-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5717657, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-21', 'accrualStartDate': '2021-06-18', 'couponRate': {'value': -0.5718182, 'unit': 'Percentage'}, 'fixingDate': '2021-06-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5718182, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-22', 'accrualStartDate': '2021-06-21', 'couponRate': {'value': -0.571889, 'unit': 'Percentage'}, 'fixingDate': '2021-06-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.571889, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-23', 'accrualStartDate': '2021-06-22', 'couponRate': {'value': -0.57192, 'unit': 'Percentage'}, 'fixingDate': '2021-06-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57192, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-24', 'accrualStartDate': '2021-06-23', 'couponRate': {'value': -0.57195103, 'unit': 'Percentage'}, 'fixingDate': '2021-06-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57195103, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-25', 'accrualStartDate': '2021-06-24', 'couponRate': {'value': -0.57198215, 'unit': 'Percentage'}, 'fixingDate': '2021-06-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57198215, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-28', 'accrualStartDate': '2021-06-25', 'couponRate': {'value': -0.5720355, 'unit': 'Percentage'}, 'fixingDate': '2021-06-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5720355, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-29', 'accrualStartDate': '2021-06-28', 'couponRate': {'value': -0.5721072, 'unit': 'Percentage'}, 'fixingDate': '2021-06-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5721072, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-30', 'accrualStartDate': '2021-06-29', 'couponRate': {'value': -0.5721386, 'unit': 'Percentage'}, 'fixingDate': '2021-06-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5721386, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-01', 'accrualStartDate': '2021-06-30', 'couponRate': {'value': -0.57217014, 'unit': 'Percentage'}, 'fixingDate': '2021-06-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57217014, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-02', 'accrualStartDate': '2021-07-01', 'couponRate': {'value': -0.57220167, 'unit': 'Percentage'}, 'fixingDate': '2021-07-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57220167, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-05', 'accrualStartDate': '2021-07-02', 'couponRate': {'value': -0.5722559, 'unit': 'Percentage'}, 'fixingDate': '2021-07-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5722559, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-06', 'accrualStartDate': '2021-07-05', 'couponRate': {'value': -0.57232946, 'unit': 'Percentage'}, 'fixingDate': '2021-07-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57232946, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-07', 'accrualStartDate': '2021-07-06', 'couponRate': {'value': -0.5723669, 'unit': 'Percentage'}, 'fixingDate': '2021-07-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5723669, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-08', 'accrualStartDate': '2021-07-07', 'couponRate': {'value': -0.57241, 'unit': 'Percentage'}, 'fixingDate': '2021-07-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57241, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-09', 'accrualStartDate': '2021-07-08', 'couponRate': {'value': -0.5724587, 'unit': 'Percentage'}, 'fixingDate': '2021-07-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5724587, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-12', 'accrualStartDate': '2021-07-09', 'couponRate': {'value': -0.5725657, 'unit': 'Percentage'}, 'fixingDate': '2021-07-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5725657, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-13', 'accrualStartDate': '2021-07-12', 'couponRate': {'value': -0.5727097, 'unit': 'Percentage'}, 'fixingDate': '2021-07-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5727097, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-14', 'accrualStartDate': '2021-07-13', 'couponRate': {'value': -0.57278645, 'unit': 'Percentage'}, 'fixingDate': '2021-07-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57278645, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-15', 'accrualStartDate': '2021-07-14', 'couponRate': {'value': -0.5728689, 'unit': 'Percentage'}, 'fixingDate': '2021-07-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5728689, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-16', 'accrualStartDate': '2021-07-15', 'couponRate': {'value': -0.5729569, 'unit': 'Percentage'}, 'fixingDate': '2021-07-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5729569, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-19', 'accrualStartDate': '2021-07-16', 'couponRate': {'value': -0.57314265, 'unit': 'Percentage'}, 'fixingDate': '2021-07-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57314265, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-20', 'accrualStartDate': '2021-07-19', 'couponRate': {'value': -0.57336533, 'unit': 'Percentage'}, 'fixingDate': '2021-07-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57336533, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-21', 'accrualStartDate': '2021-07-20', 'couponRate': {'value': -0.5734815, 'unit': 'Percentage'}, 'fixingDate': '2021-07-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5734815, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-22', 'accrualStartDate': '2021-07-21', 'couponRate': {'value': -0.5736033, 'unit': 'Percentage'}, 'fixingDate': '2021-07-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5736033, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-23', 'accrualStartDate': '2021-07-22', 'couponRate': {'value': -0.57373065, 'unit': 'Percentage'}, 'fixingDate': '2021-07-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57373065, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-26', 'accrualStartDate': '2021-07-23', 'couponRate': {'value': -0.573995, 'unit': 'Percentage'}, 'fixingDate': '2021-07-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.573995, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-27', 'accrualStartDate': '2021-07-26', 'couponRate': {'value': -0.5742964, 'unit': 'Percentage'}, 'fixingDate': '2021-07-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5742964, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-28', 'accrualStartDate': '2021-07-27', 'couponRate': {'value': -0.5744519, 'unit': 'Percentage'}, 'fixingDate': '2021-07-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5744519, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-29', 'accrualStartDate': '2021-07-28', 'couponRate': {'value': -0.574613, 'unit': 'Percentage'}, 'fixingDate': '2021-07-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.574613, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-30', 'accrualStartDate': '2021-07-29', 'couponRate': {'value': -0.57477975, 'unit': 'Percentage'}, 'fixingDate': '2021-07-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57477975, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-02', 'accrualStartDate': '2021-07-30', 'couponRate': {'value': -0.5751227, 'unit': 'Percentage'}, 'fixingDate': '2021-07-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5751227, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-03', 'accrualStartDate': '2021-08-02', 'couponRate': {'value': -0.57550275, 'unit': 'Percentage'}, 'fixingDate': '2021-08-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57550275, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-04', 'accrualStartDate': '2021-08-03', 'couponRate': {'value': -0.57569754, 'unit': 'Percentage'}, 'fixingDate': '2021-08-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57569754, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-05', 'accrualStartDate': '2021-08-04', 'couponRate': {'value': -0.57589656, 'unit': 'Percentage'}, 'fixingDate': '2021-08-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57589656, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-06', 'accrualStartDate': '2021-08-05', 'couponRate': {'value': -0.57609415, 'unit': 'Percentage'}, 'fixingDate': '2021-08-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57609415, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-09', 'accrualStartDate': '2021-08-06', 'couponRate': {'value': -0.5764708, 'unit': 'Percentage'}, 'fixingDate': '2021-08-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5764708, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-10', 'accrualStartDate': '2021-08-09', 'couponRate': {'value': -0.57685655, 'unit': 'Percentage'}, 'fixingDate': '2021-08-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57685655, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-11', 'accrualStartDate': '2021-08-10', 'couponRate': {'value': -0.57704014, 'unit': 'Percentage'}, 'fixingDate': '2021-08-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57704014, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-12', 'accrualStartDate': '2021-08-11', 'couponRate': {'value': -0.577221, 'unit': 'Percentage'}, 'fixingDate': '2021-08-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.577221, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-13', 'accrualStartDate': '2021-08-12', 'couponRate': {'value': -0.57739896, 'unit': 'Percentage'}, 'fixingDate': '2021-08-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57739896, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-16', 'accrualStartDate': '2021-08-13', 'couponRate': {'value': -0.57773626, 'unit': 'Percentage'}, 'fixingDate': '2021-08-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57773626, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-17', 'accrualStartDate': '2021-08-16', 'couponRate': {'value': -0.57808286, 'unit': 'Percentage'}, 'fixingDate': '2021-08-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57808286, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-18', 'accrualStartDate': '2021-08-17', 'couponRate': {'value': -0.57824683, 'unit': 'Percentage'}, 'fixingDate': '2021-08-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57824683, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-19', 'accrualStartDate': '2021-08-18', 'couponRate': {'value': -0.57840794, 'unit': 'Percentage'}, 'fixingDate': '2021-08-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57840794, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-20', 'accrualStartDate': '2021-08-19', 'couponRate': {'value': -0.5785663, 'unit': 'Percentage'}, 'fixingDate': '2021-08-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5785663, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-23', 'accrualStartDate': '2021-08-20', 'couponRate': {'value': -0.5788644, 'unit': 'Percentage'}, 'fixingDate': '2021-08-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5788644, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-24', 'accrualStartDate': '2021-08-23', 'couponRate': {'value': -0.5791718, 'unit': 'Percentage'}, 'fixingDate': '2021-08-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5791718, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-25', 'accrualStartDate': '2021-08-24', 'couponRate': {'value': -0.57931614, 'unit': 'Percentage'}, 'fixingDate': '2021-08-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57931614, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-26', 'accrualStartDate': '2021-08-25', 'couponRate': {'value': -0.5794577, 'unit': 'Percentage'}, 'fixingDate': '2021-08-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5794577, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-27', 'accrualStartDate': '2021-08-26', 'couponRate': {'value': -0.57959646, 'unit': 'Percentage'}, 'fixingDate': '2021-08-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57959646, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-30', 'accrualStartDate': '2021-08-27', 'couponRate': {'value': -0.57985526, 'unit': 'Percentage'}, 'fixingDate': '2021-08-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57985526, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-31', 'accrualStartDate': '2021-08-30', 'couponRate': {'value': -0.5801235, 'unit': 'Percentage'}, 'fixingDate': '2021-08-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5801235, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-01', 'accrualStartDate': '2021-08-31', 'couponRate': {'value': -0.58024824, 'unit': 'Percentage'}, 'fixingDate': '2021-08-31', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58024824, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-02', 'accrualStartDate': '2021-09-01', 'couponRate': {'value': -0.5803702, 'unit': 'Percentage'}, 'fixingDate': '2021-09-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5803702, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-03', 'accrualStartDate': '2021-09-02', 'couponRate': {'value': -0.58048934, 'unit': 'Percentage'}, 'fixingDate': '2021-09-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58048934, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-06', 'accrualStartDate': '2021-09-03', 'couponRate': {'value': -0.5807089, 'unit': 'Percentage'}, 'fixingDate': '2021-09-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5807089, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-07', 'accrualStartDate': '2021-09-06', 'couponRate': {'value': -0.58093846, 'unit': 'Percentage'}, 'fixingDate': '2021-09-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58093846, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-08', 'accrualStartDate': '2021-09-07', 'couponRate': {'value': -0.5810467, 'unit': 'Percentage'}, 'fixingDate': '2021-09-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5810467, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-09', 'accrualStartDate': '2021-09-08', 'couponRate': {'value': -0.5811552, 'unit': 'Percentage'}, 'fixingDate': '2021-09-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5811552, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-10', 'accrualStartDate': '2021-09-09', 'couponRate': {'value': -0.58126396, 'unit': 'Percentage'}, 'fixingDate': '2021-09-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58126396, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-13', 'accrualStartDate': '2021-09-10', 'couponRate': {'value': -0.58147305, 'unit': 'Percentage'}, 'fixingDate': '2021-09-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58147305, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-14', 'accrualStartDate': '2021-09-13', 'couponRate': {'value': -0.5817018, 'unit': 'Percentage'}, 'fixingDate': '2021-09-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5817018, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-15', 'accrualStartDate': '2021-09-14', 'couponRate': {'value': -0.58181196, 'unit': 'Percentage'}, 'fixingDate': '2021-09-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58181196, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-16', 'accrualStartDate': '2021-09-15', 'couponRate': {'value': -0.5819224, 'unit': 'Percentage'}, 'fixingDate': '2021-09-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5819224, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-17', 'accrualStartDate': '2021-09-16', 'couponRate': {'value': -0.5820331, 'unit': 'Percentage'}, 'fixingDate': '2021-09-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5820331, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-20', 'accrualStartDate': '2021-09-17', 'couponRate': {'value': -0.58224595, 'unit': 'Percentage'}, 'fixingDate': '2021-09-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58224595, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-21', 'accrualStartDate': '2021-09-20', 'couponRate': {'value': -0.5824786, 'unit': 'Percentage'}, 'fixingDate': '2021-09-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5824786, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-22', 'accrualStartDate': '2021-09-21', 'couponRate': {'value': -0.58259064, 'unit': 'Percentage'}, 'fixingDate': '2021-09-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58259064, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-23', 'accrualStartDate': '2021-09-22', 'couponRate': {'value': -0.58270293, 'unit': 'Percentage'}, 'fixingDate': '2021-09-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58270293, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-24', 'accrualStartDate': '2021-09-23', 'couponRate': {'value': -0.5828155, 'unit': 'Percentage'}, 'fixingDate': '2021-09-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5828155, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-27', 'accrualStartDate': '2021-09-24', 'couponRate': {'value': -0.58303225, 'unit': 'Percentage'}, 'fixingDate': '2021-09-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58303225, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-28', 'accrualStartDate': '2021-09-27', 'couponRate': {'value': -0.5832687, 'unit': 'Percentage'}, 'fixingDate': '2021-09-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5832687, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-29', 'accrualStartDate': '2021-09-28', 'couponRate': {'value': -0.58338267, 'unit': 'Percentage'}, 'fixingDate': '2021-09-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58338267, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-30', 'accrualStartDate': '2021-09-29', 'couponRate': {'value': -0.5834969, 'unit': 'Percentage'}, 'fixingDate': '2021-09-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5834969, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-01', 'accrualStartDate': '2021-09-30', 'couponRate': {'value': -0.5836114, 'unit': 'Percentage'}, 'fixingDate': '2021-09-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5836114, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-04', 'accrualStartDate': '2021-10-01', 'couponRate': {'value': -0.58383185, 'unit': 'Percentage'}, 'fixingDate': '2021-10-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58383185, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-05', 'accrualStartDate': '2021-10-04', 'couponRate': {'value': -0.58407223, 'unit': 'Percentage'}, 'fixingDate': '2021-10-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58407223, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-06', 'accrualStartDate': '2021-10-05', 'couponRate': {'value': -0.58418834, 'unit': 'Percentage'}, 'fixingDate': '2021-10-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58418834, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-07', 'accrualStartDate': '2021-10-06', 'couponRate': {'value': -0.584305, 'unit': 'Percentage'}, 'fixingDate': '2021-10-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.584305, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-08', 'accrualStartDate': '2021-10-07', 'couponRate': {'value': -0.5844222, 'unit': 'Percentage'}, 'fixingDate': '2021-10-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5844222, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-11', 'accrualStartDate': '2021-10-08', 'couponRate': {'value': -0.58464867, 'unit': 'Percentage'}, 'fixingDate': '2021-10-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58464867, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-12', 'accrualStartDate': '2021-10-11', 'couponRate': {'value': -0.58489597, 'unit': 'Percentage'}, 'fixingDate': '2021-10-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58489597, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-13', 'accrualStartDate': '2021-10-12', 'couponRate': {'value': -0.5850157, 'unit': 'Percentage'}, 'fixingDate': '2021-10-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5850157, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-14', 'accrualStartDate': '2021-10-13', 'couponRate': {'value': -0.585136, 'unit': 'Percentage'}, 'fixingDate': '2021-10-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.585136, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-15', 'accrualStartDate': '2021-10-14', 'couponRate': {'value': -0.58525676, 'unit': 'Percentage'}, 'fixingDate': '2021-10-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58525676, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-18', 'accrualStartDate': '2021-10-15', 'couponRate': {'value': -0.5854905, 'unit': 'Percentage'}, 'fixingDate': '2021-10-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5854905, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-19', 'accrualStartDate': '2021-10-18', 'couponRate': {'value': -0.5857451, 'unit': 'Percentage'}, 'fixingDate': '2021-10-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5857451, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-20', 'accrualStartDate': '2021-10-19', 'couponRate': {'value': -0.5858685, 'unit': 'Percentage'}, 'fixingDate': '2021-10-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5858685, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-21', 'accrualStartDate': '2021-10-20', 'couponRate': {'value': -0.58599234, 'unit': 'Percentage'}, 'fixingDate': '2021-10-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58599234, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-22', 'accrualStartDate': '2021-10-21', 'couponRate': {'value': -0.58611673, 'unit': 'Percentage'}, 'fixingDate': '2021-10-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58611673, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-25', 'accrualStartDate': '2021-10-22', 'couponRate': {'value': -0.5863578, 'unit': 'Percentage'}, 'fixingDate': '2021-10-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5863578, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-26', 'accrualStartDate': '2021-10-25', 'couponRate': {'value': -0.58661956, 'unit': 'Percentage'}, 'fixingDate': '2021-10-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58661956, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-27', 'accrualStartDate': '2021-10-26', 'couponRate': {'value': -0.5867466, 'unit': 'Percentage'}, 'fixingDate': '2021-10-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5867466, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-28', 'accrualStartDate': '2021-10-27', 'couponRate': {'value': -0.58687407, 'unit': 'Percentage'}, 'fixingDate': '2021-10-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58687407, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-29', 'accrualStartDate': '2021-10-28', 'couponRate': {'value': -0.5870021, 'unit': 'Percentage'}, 'fixingDate': '2021-10-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5870021, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-01', 'accrualStartDate': '2021-10-29', 'couponRate': {'value': -0.58725035, 'unit': 'Percentage'}, 'fixingDate': '2021-10-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58725035, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-02', 'accrualStartDate': '2021-11-01', 'couponRate': {'value': -0.5875194, 'unit': 'Percentage'}, 'fixingDate': '2021-11-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5875194, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-03', 'accrualStartDate': '2021-11-02', 'couponRate': {'value': -0.58765006, 'unit': 'Percentage'}, 'fixingDate': '2021-11-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58765006, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-04', 'accrualStartDate': '2021-11-03', 'couponRate': {'value': -0.5877812, 'unit': 'Percentage'}, 'fixingDate': '2021-11-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5877812, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-05', 'accrualStartDate': '2021-11-04', 'couponRate': {'value': -0.5879125, 'unit': 'Percentage'}, 'fixingDate': '2021-11-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5879125, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-08', 'accrualStartDate': '2021-11-05', 'couponRate': {'value': -0.58816105, 'unit': 'Percentage'}, 'fixingDate': '2021-11-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58816105, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-09', 'accrualStartDate': '2021-11-08', 'couponRate': {'value': -0.58842367, 'unit': 'Percentage'}, 'fixingDate': '2021-11-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58842367, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-10', 'accrualStartDate': '2021-11-09', 'couponRate': {'value': -0.5885476, 'unit': 'Percentage'}, 'fixingDate': '2021-11-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5885476, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-11', 'accrualStartDate': '2021-11-10', 'couponRate': {'value': -0.58866996, 'unit': 'Percentage'}, 'fixingDate': '2021-11-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58866996, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-12', 'accrualStartDate': '2021-11-11', 'couponRate': {'value': -0.5887908, 'unit': 'Percentage'}, 'fixingDate': '2021-11-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5887908, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-15', 'accrualStartDate': '2021-11-12', 'couponRate': {'value': -0.5890177, 'unit': 'Percentage'}, 'fixingDate': '2021-11-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5890177, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-16', 'accrualStartDate': '2021-11-15', 'couponRate': {'value': -0.5892587, 'unit': 'Percentage'}, 'fixingDate': '2021-11-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5892587, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-17', 'accrualStartDate': '2021-11-16', 'couponRate': {'value': -0.5893718, 'unit': 'Percentage'}, 'fixingDate': '2021-11-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5893718, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-18', 'accrualStartDate': '2021-11-17', 'couponRate': {'value': -0.5894834, 'unit': 'Percentage'}, 'fixingDate': '2021-11-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5894834, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-19', 'accrualStartDate': '2021-11-18', 'couponRate': {'value': -0.58959335, 'unit': 'Percentage'}, 'fixingDate': '2021-11-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58959335, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-22', 'accrualStartDate': '2021-11-19', 'couponRate': {'value': -0.5897986, 'unit': 'Percentage'}, 'fixingDate': '2021-11-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5897986, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-23', 'accrualStartDate': '2021-11-22', 'couponRate': {'value': -0.59001803, 'unit': 'Percentage'}, 'fixingDate': '2021-11-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59001803, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-24', 'accrualStartDate': '2021-11-23', 'couponRate': {'value': -0.5901203, 'unit': 'Percentage'}, 'fixingDate': '2021-11-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5901203, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-25', 'accrualStartDate': '2021-11-24', 'couponRate': {'value': -0.5902211, 'unit': 'Percentage'}, 'fixingDate': '2021-11-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5902211, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-26', 'accrualStartDate': '2021-11-25', 'couponRate': {'value': -0.5903203, 'unit': 'Percentage'}, 'fixingDate': '2021-11-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5903203, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-29', 'accrualStartDate': '2021-11-26', 'couponRate': {'value': -0.5905039, 'unit': 'Percentage'}, 'fixingDate': '2021-11-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5905039, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-30', 'accrualStartDate': '2021-11-29', 'couponRate': {'value': -0.5907017, 'unit': 'Percentage'}, 'fixingDate': '2021-11-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5907017, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-01', 'accrualStartDate': '2021-11-30', 'couponRate': {'value': -0.5907932, 'unit': 'Percentage'}, 'fixingDate': '2021-11-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5907932, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-02', 'accrualStartDate': '2021-12-01', 'couponRate': {'value': -0.59088314, 'unit': 'Percentage'}, 'fixingDate': '2021-12-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59088314, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-03', 'accrualStartDate': '2021-12-02', 'couponRate': {'value': -0.5909716, 'unit': 'Percentage'}, 'fixingDate': '2021-12-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5909716, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-06', 'accrualStartDate': '2021-12-03', 'couponRate': {'value': -0.59113353, 'unit': 'Percentage'}, 'fixingDate': '2021-12-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59113353, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-07', 'accrualStartDate': '2021-12-06', 'couponRate': {'value': -0.5913089, 'unit': 'Percentage'}, 'fixingDate': '2021-12-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5913089, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-08', 'accrualStartDate': '2021-12-07', 'couponRate': {'value': -0.5913841, 'unit': 'Percentage'}, 'fixingDate': '2021-12-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5913841, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-09', 'accrualStartDate': '2021-12-08', 'couponRate': {'value': -0.59145236, 'unit': 'Percentage'}, 'fixingDate': '2021-12-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59145236, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-10', 'accrualStartDate': '2021-12-09', 'couponRate': {'value': -0.59151363, 'unit': 'Percentage'}, 'fixingDate': '2021-12-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59151363, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-13', 'accrualStartDate': '2021-12-10', 'couponRate': {'value': -0.5916031, 'unit': 'Percentage'}, 'fixingDate': '2021-12-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5916031, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-14', 'accrualStartDate': '2021-12-13', 'couponRate': {'value': -0.5916887, 'unit': 'Percentage'}, 'fixingDate': '2021-12-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5916887, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-15', 'accrualStartDate': '2021-12-14', 'couponRate': {'value': -0.591715, 'unit': 'Percentage'}, 'fixingDate': '2021-12-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.591715, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-16', 'accrualStartDate': '2021-12-15', 'couponRate': {'value': -0.59173423, 'unit': 'Percentage'}, 'fixingDate': '2021-12-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59173423, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-17', 'accrualStartDate': '2021-12-16', 'couponRate': {'value': -0.59174657, 'unit': 'Percentage'}, 'fixingDate': '2021-12-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59174657, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-20', 'accrualStartDate': '2021-12-17', 'couponRate': {'value': -0.5917381, 'unit': 'Percentage'}, 'fixingDate': '2021-12-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5917381, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-21', 'accrualStartDate': '2021-12-20', 'couponRate': {'value': -0.5917258, 'unit': 'Percentage'}, 'fixingDate': '2021-12-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5917258, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-22', 'accrualStartDate': '2021-12-21', 'couponRate': {'value': -0.5917032, 'unit': 'Percentage'}, 'fixingDate': '2021-12-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5917032, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-23', 'accrualStartDate': '2021-12-22', 'couponRate': {'value': -0.59167355, 'unit': 'Percentage'}, 'fixingDate': '2021-12-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59167355, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-24', 'accrualStartDate': '2021-12-23', 'couponRate': {'value': -0.59163696, 'unit': 'Percentage'}, 'fixingDate': '2021-12-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59163696, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-27', 'accrualStartDate': '2021-12-24', 'couponRate': {'value': -0.5915307, 'unit': 'Percentage'}, 'fixingDate': '2021-12-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5915307, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-28', 'accrualStartDate': '2021-12-27', 'couponRate': {'value': -0.59142053, 'unit': 'Percentage'}, 'fixingDate': '2021-12-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59142053, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-29', 'accrualStartDate': '2021-12-28', 'couponRate': {'value': -0.591349, 'unit': 'Percentage'}, 'fixingDate': '2021-12-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.591349, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-30', 'accrualStartDate': '2021-12-29', 'couponRate': {'value': -0.59127045, 'unit': 'Percentage'}, 'fixingDate': '2021-12-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59127045, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-31', 'accrualStartDate': '2021-12-30', 'couponRate': {'value': -0.5911849, 'unit': 'Percentage'}, 'fixingDate': '2021-12-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5911849, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-03', 'accrualStartDate': '2021-12-31', 'couponRate': {'value': -0.5909808, 'unit': 'Percentage'}, 'fixingDate': '2021-12-31', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5909808, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-04', 'accrualStartDate': '2022-01-03', 'couponRate': {'value': -0.5907729, 'unit': 'Percentage'}, 'fixingDate': '2022-01-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5907729, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-05', 'accrualStartDate': '2022-01-04', 'couponRate': {'value': -0.5906539, 'unit': 'Percentage'}, 'fixingDate': '2022-01-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5906539, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-06', 'accrualStartDate': '2022-01-05', 'couponRate': {'value': -0.5905351, 'unit': 'Percentage'}, 'fixingDate': '2022-01-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5905351, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-07', 'accrualStartDate': '2022-01-06', 'couponRate': {'value': -0.590418, 'unit': 'Percentage'}, 'fixingDate': '2022-01-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.590418, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-10', 'accrualStartDate': '2022-01-07', 'couponRate': {'value': -0.5901796, 'unit': 'Percentage'}, 'fixingDate': '2022-01-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5901796, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-11', 'accrualStartDate': '2022-01-10', 'couponRate': {'value': -0.5899662, 'unit': 'Percentage'}, 'fixingDate': '2022-01-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5899662, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-12', 'accrualStartDate': '2022-01-11', 'couponRate': {'value': -0.5898574, 'unit': 'Percentage'}, 'fixingDate': '2022-01-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5898574, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-13', 'accrualStartDate': '2022-01-12', 'couponRate': {'value': -0.58975023, 'unit': 'Percentage'}, 'fixingDate': '2022-01-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58975023, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-14', 'accrualStartDate': '2022-01-13', 'couponRate': {'value': -0.5896448, 'unit': 'Percentage'}, 'fixingDate': '2022-01-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5896448, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-17', 'accrualStartDate': '2022-01-14', 'couponRate': {'value': -0.58942974, 'unit': 'Percentage'}, 'fixingDate': '2022-01-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58942974, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-18', 'accrualStartDate': '2022-01-17', 'couponRate': {'value': -0.5892396, 'unit': 'Percentage'}, 'fixingDate': '2022-01-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5892396, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-19', 'accrualStartDate': '2022-01-18', 'couponRate': {'value': -0.58914244, 'unit': 'Percentage'}, 'fixingDate': '2022-01-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58914244, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-20', 'accrualStartDate': '2022-01-19', 'couponRate': {'value': -0.58904696, 'unit': 'Percentage'}, 'fixingDate': '2022-01-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58904696, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-21', 'accrualStartDate': '2022-01-20', 'couponRate': {'value': -0.58895314, 'unit': 'Percentage'}, 'fixingDate': '2022-01-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58895314, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-24', 'accrualStartDate': '2022-01-21', 'couponRate': {'value': -0.58876145, 'unit': 'Percentage'}, 'fixingDate': '2022-01-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58876145, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-25', 'accrualStartDate': '2022-01-24', 'couponRate': {'value': -0.58859456, 'unit': 'Percentage'}, 'fixingDate': '2022-01-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58859456, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-26', 'accrualStartDate': '2022-01-25', 'couponRate': {'value': -0.5885091, 'unit': 'Percentage'}, 'fixingDate': '2022-01-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5885091, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-27', 'accrualStartDate': '2022-01-26', 'couponRate': {'value': -0.5884253, 'unit': 'Percentage'}, 'fixingDate': '2022-01-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5884253, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-28', 'accrualStartDate': '2022-01-27', 'couponRate': {'value': -0.5883431, 'unit': 'Percentage'}, 'fixingDate': '2022-01-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5883431, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-31', 'accrualStartDate': '2022-01-28', 'couponRate': {'value': -0.5881747, 'unit': 'Percentage'}, 'fixingDate': '2022-01-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5881747, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-01', 'accrualStartDate': '2022-01-31', 'couponRate': {'value': -0.58803105, 'unit': 'Percentage'}, 'fixingDate': '2022-01-31', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58803105, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-02', 'accrualStartDate': '2022-02-01', 'couponRate': {'value': -0.58795726, 'unit': 'Percentage'}, 'fixingDate': '2022-02-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58795726, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-03', 'accrualStartDate': '2022-02-02', 'couponRate': {'value': -0.5878851, 'unit': 'Percentage'}, 'fixingDate': '2022-02-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5878851, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-04', 'accrualStartDate': '2022-02-03', 'couponRate': {'value': -0.5878145, 'unit': 'Percentage'}, 'fixingDate': '2022-02-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5878145, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-07', 'accrualStartDate': '2022-02-04', 'couponRate': {'value': -0.58769184, 'unit': 'Percentage'}, 'fixingDate': '2022-02-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58769184, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-08', 'accrualStartDate': '2022-02-07', 'couponRate': {'value': -0.58764124, 'unit': 'Percentage'}, 'fixingDate': '2022-02-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58764124, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-09', 'accrualStartDate': '2022-02-08', 'couponRate': {'value': -0.5876388, 'unit': 'Percentage'}, 'fixingDate': '2022-02-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5876388, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-10', 'accrualStartDate': '2022-02-09', 'couponRate': {'value': -0.587653, 'unit': 'Percentage'}, 'fixingDate': '2022-02-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.587653, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-11', 'accrualStartDate': '2022-02-10', 'couponRate': {'value': -0.58768374, 'unit': 'Percentage'}, 'fixingDate': '2022-02-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58768374, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-14', 'accrualStartDate': '2022-02-11', 'couponRate': {'value': -0.587791, 'unit': 'Percentage'}, 'fixingDate': '2022-02-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.587791, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-15', 'accrualStartDate': '2022-02-14', 'couponRate': {'value': -0.5879729, 'unit': 'Percentage'}, 'fixingDate': '2022-02-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5879729, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-16', 'accrualStartDate': '2022-02-15', 'couponRate': {'value': -0.5880866, 'unit': 'Percentage'}, 'fixingDate': '2022-02-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5880866, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-17', 'accrualStartDate': '2022-02-16', 'couponRate': {'value': -0.588217, 'unit': 'Percentage'}, 'fixingDate': '2022-02-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.588217, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-18', 'accrualStartDate': '2022-02-17', 'couponRate': {'value': -0.58836395, 'unit': 'Percentage'}, 'fixingDate': '2022-02-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58836395, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-21', 'accrualStartDate': '2022-02-18', 'couponRate': {'value': -0.5887036, 'unit': 'Percentage'}, 'fixingDate': '2022-02-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5887036, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-22', 'accrualStartDate': '2022-02-21', 'couponRate': {'value': -0.5891177, 'unit': 'Percentage'}, 'fixingDate': '2022-02-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5891177, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-23', 'accrualStartDate': '2022-02-22', 'couponRate': {'value': -0.58934766, 'unit': 'Percentage'}, 'fixingDate': '2022-02-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58934766, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-24', 'accrualStartDate': '2022-02-23', 'couponRate': {'value': -0.5895941, 'unit': 'Percentage'}, 'fixingDate': '2022-02-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5895941, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-25', 'accrualStartDate': '2022-02-24', 'couponRate': {'value': -0.5898572, 'unit': 'Percentage'}, 'fixingDate': '2022-02-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5898572, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-28', 'accrualStartDate': '2022-02-25', 'couponRate': {'value': -0.590429, 'unit': 'Percentage'}, 'fixingDate': '2022-02-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.590429, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-03-01', 'accrualStartDate': '2022-02-28', 'couponRate': {'value': -0.5910755, 'unit': 'Percentage'}, 'fixingDate': '2022-02-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5910755, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-03-02', 'accrualStartDate': '2022-03-01', 'couponRate': {'value': -0.5914215, 'unit': 'Percentage'}, 'fixingDate': '2022-03-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5914215, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2022-03-02'}, 'amount': {'value': -5857.234780494486, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.5929854034229001, 'unit': 'Percentage'}, 'discountFactor': 1.0119759592460968, 'startDate': '2022-03-02', 'endDate': '2023-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.5934726969362814, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2023-03-02', 'accrualStartDate': '2022-03-02', 'couponRate': {'value': -0.5929854, 'unit': 'Percentage'}, 'fixingDate': '2022-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5929854, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2023-03-02'}, 'amount': {'value': -6012.213118037736, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.5900714270630001, 'unit': 'Percentage'}, 'discountFactor': 1.0181170798500445, 'startDate': '2023-03-02', 'endDate': '2024-03-04', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.595625297376734, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2024-03-04', 'accrualStartDate': '2023-03-02', 'couponRate': {'value': -0.59007144, 'unit': 'Percentage'}, 'fixingDate': '2023-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59007144, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2024-03-04'}, 'amount': {'value': -6031.841254421778, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.3825091872524, 'unit': 'Percentage'}, 'discountFactor': 1.0220700306369428, 'startDate': '2024-03-04', 'endDate': '2025-03-03', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.54389228911631, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2025-03-03', 'accrualStartDate': '2024-03-04', 'couponRate': {'value': -0.3825092, 'unit': 'Percentage'}, 'fixingDate': '2024-03-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.3825092, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2025-03-03'}, 'amount': {'value': -3867.5928933298223, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.31769169686550003, 'unit': 'Percentage'}, 'discountFactor': 1.0253637204327237, 'startDate': '2025-03-03', 'endDate': '2026-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.4996953251847902, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2026-03-02', 'accrualStartDate': '2025-03-03', 'couponRate': {'value': -0.31769168, 'unit': 'Percentage'}, 'fixingDate': '2025-03-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.31769168, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2026-03-02'}, 'amount': {'value': -3212.2160460845, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.1412312105185, 'unit': 'Percentage'}, 'discountFactor': 1.0268340724314076, 'startDate': '2026-03-02', 'endDate': '2027-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.44036673946632465, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2027-03-02', 'accrualStartDate': '2026-03-02', 'couponRate': {'value': -0.14123121, 'unit': 'Percentage'}, 'fixingDate': '2026-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.14123121, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2027-03-02'}, 'amount': {'value': -1431.9275510903472, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.0031376447609000003, 'unit': 'Percentage'}, 'discountFactor': 1.026866828855218, 'startDate': '2027-03-02', 'endDate': '2028-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.37803012430979166, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2028-03-02', 'accrualStartDate': '2027-03-02', 'couponRate': {'value': -0.0031376448, 'unit': 'Percentage'}, 'fixingDate': '2027-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.0031376448, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2028-03-02'}, 'amount': {'value': -31.899388402483332, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': 0.1386636808419, 'unit': 'Percentage'}, 'discountFactor': 1.0254251880409235, 'startDate': '2028-03-02', 'endDate': '2029-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.3133498336461038, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2029-03-02', 'accrualStartDate': '2028-03-02', 'couponRate': {'value': 0.13866368, 'unit': 'Percentage'}, 'fixingDate': '2028-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': 0.13866368, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2029-03-02'}, 'amount': {'value': 1405.895652980375, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': 0.2503159110993, 'unit': 'Percentage'}, 'discountFactor': 1.0228151360055724, 'startDate': '2029-03-02', 'endDate': '2030-03-04', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.2501869192443773, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2030-03-04', 'accrualStartDate': '2029-03-02', 'couponRate': {'value': 0.2503159, 'unit': 'Percentage'}, 'fixingDate': '2029-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': 0.2503159, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2030-03-04'}, 'amount': {'value': 2551.8316492623085, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': 0.4119642484185, 'unit': 'Percentage'}, 'discountFactor': 1.0185723581130723, 'startDate': '2030-03-04', 'endDate': '2031-03-03', 'remainingNotional': 0.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.18380045671523293, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2031-03-03', 'accrualStartDate': '2030-03-04', 'couponRate': {'value': 0.41196424, 'unit': 'Percentage'}, 'fixingDate': '2030-03-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': 0.41196424, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2031-03-03'}, 'amount': {'value': 4165.416289564833, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}]}]}

    """

    try:
        logger.info("Calling price")

        response = Client().loans_resource.price(
            fields=fields,
            definitions=definitions,
            pricing_preferences=pricing_preferences,
            market_data=market_data,
            return_market_data=return_market_data,
        )

        output = response.data
        logger.info("Called price")

        return output
    except Exception as err:
        logger.error("Error price.")
        check_exception_and_raise(err, logger)


def search(
    *,
    item_per_page: Optional[int] = None,
    page: Optional[int] = None,
    spaces: Optional[List[str]] = None,
    names: Optional[List[str]] = None,
    space_name_sort_order: Optional[Union[str, SortingOrderEnum]] = None,
    tags: Optional[List[str]] = None,
    fields: Optional[str] = None,
) -> List[LoanAsCollectionItem]:
    """
    List the Loans existing in the platform (depending on permissions)

    Parameters
    ----------
    item_per_page : int, optional
        A parameter used to select the number of items allowed per page. The valid range is 1-500. If not provided, 50 will be used.
    page : int, optional
        A parameter used to define the page number to display.
    spaces : List[str], optional
        A parameter used to search for platform resources stored in a given space. Space is like a namespace where resources are stored. By default there are two spaces:
        LSEG is reserved for LSEG maintained resources, HOME is reserved for user's default space.
        If space is not specified, it will search within all spaces.
    names : List[str], optional
        A parameter used to search for platform resources with given names.
    space_name_sort_order : Union[str, SortingOrderEnum], optional
        A parameter used to sort platform resources by name based on a defined order.
    tags : List[str], optional
        A parameter used to search for platform resources with given tags.
    fields : str, optional
        A parameter used to select the fields to return in response. If not provided, all fields will be returned.
        Some usage examples:
        1. Simply enumerating the fields, separating them by ',', e.g. 'fields=//please insert the selected fields here, e.g., field1, field2 //'
        2. Using parentheses to indicate nesting, e.g. 'fields= //please insert the selected field and subfields here, e.g., field1(subfield1, subfield2), field2(subfield3)//’
        3. Using forward slash '/' to indicate nesting, e.g. 'fields=//please insert the selected field and subfields here, e.g.,  field1/subfield1, field1/subfield2, field2/subfield3//’ (same result as example above)
        4. Operators can even be combined (forward slashes in brackets, not the way around), e.g. 'fields=//please insert the selected field and subfields here, e.g.,  field1(subfield1/subsubfield1), field2/subfield2//'

    Returns
    --------
    List[LoanAsCollectionItem]
        A model template defining the partial description of the resource returned by the GET list service.

    Examples
    --------
    >>> # execute the search of loan templates
    >>> loan_templates = search()
    >>>
    >>> print(loan_templates)
    [{'type': 'Loan', 'id': '1b7dd5de-5dea-463d-8624-6120eaf171b3', 'location': {'space': 'HOME', 'name': 'TestLoan1750953126327056'}, 'description': {'summary': 'Test description', 'tags': ['tag1', 'tag2']}}]

    """

    try:
        logger.info("Calling search")

        response = Client().loans_resource.list(
            item_per_page=item_per_page,
            page=page,
            spaces=spaces,
            names=names,
            space_name_sort_order=space_name_sort_order,
            tags=tags,
            fields=fields,
        )

        output = response.data
        logger.info("Called search")

        return output
    except Exception as err:
        logger.error("Error search.")
        check_exception_and_raise(err, logger)


def value(
    *,
    definitions: List[LoanDefinitionInstrument],
    pricing_preferences: Optional[IrPricingParameters] = None,
    market_data: Optional[MarketData] = None,
    return_market_data: Optional[bool] = None,
    fields: Optional[str] = None,
) -> LoanInstrumentValuationResponseFieldsResponseData:
    """
    Calculate the market value of loans provided in the request.

    Parameters
    ----------
    definitions : List[LoanDefinitionInstrument]
        An array of objects describing a curve or an instrument.
        Please provide either a full definition (for a user-defined curve/instrument), or reference to a curve/instrument definition saved in the platform, or the code identifying the existing curve/instrument.
    pricing_preferences : IrPricingParameters, optional
        The parameters that control the computation of the analytics.
    market_data : MarketData, optional
        The market data used to compute the analytics.
    return_market_data : bool, optional
        Boolean property to determine if undelying market data used for calculation should be returned in the response
    fields : str, optional
        A parameter used to select the fields to return in response. If not provided, all fields will be returned.
        Some usage examples:
        1. Simply enumerating the fields, separating them by ',', e.g. 'fields=//please insert the selected fields here, e.g., field1, field2 //'
        2. Using parentheses to indicate nesting, e.g. 'fields= //please insert the selected field and subfields here, e.g., field1(subfield1, subfield2), field2(subfield3)//’
        3. Using forward slash '/' to indicate nesting, e.g. 'fields=//please insert the selected field and subfields here, e.g.,  field1/subfield1, field1/subfield2, field2/subfield3//’ (same result as example above)
        4. Operators can even be combined (forward slashes in brackets, not the way around), e.g. 'fields=//please insert the selected field and subfields here, e.g.,  field1(subfield1/subsubfield1), field2/subfield2//'

    Returns
    --------
    LoanInstrumentValuationResponseFieldsResponseData


    Examples
    --------
    >>> business_day_adj = BusinessDayAdjustmentDefinition(calendars= [] , convention= "ModifiedFollowing")
    >>> start = AdjustableDate(date= "2021-03-02")
    >>> end =  RelativeAdjustableDate( reference_date= "StartDate", tenor= "10Y")
    >>> rate_definition = FloatingRateDefinition(index= "LSEG/EUR_ESTR_ON_FTSE")
    >>> interest_periods = ScheduleDefinition(business_day_adjustment= business_day_adj, start_date= start , end_date= end,frequency= "Annual", roll_convention= "Same")
    >>> offset_def = OffsetDefinition( business_day_adjustment= business_day_adj, direction= "Backward", reference_date= "PeriodEndDate", tenor= "0D" )
    >>> principal_definition = PrincipalDefinition( amount= 1000000, currency= "EUR")
    >>> loan_definition  = LoanDefinition(rate=rate_definition, interest_periods= interest_periods, payment_offset= offset_def, coupon_day_count= 'Dcb_Actual_360', accrual_day_count= 'Dcb_Actual_360', principal= principal_definition, payer= 'Party2', receiver= 'Party1')


    >>> loan_definition_Instrument = LoanDefinitionInstrument(definition=loan_definition)
    >>> pricing_parameters = IrPricingParameters( valuation_date= '2021-03-02')


    >>> value_result = value(definitions= [loan_definition_Instrument], pricing_preferences= pricing_parameters)
    >>> print(value_result)
    {'definitions': [{'definition': {'rate': {'interestRateType': 'FloatingRate', 'index': 'LSEG/EUR_ESTR_ON_FTSE', 'leverage': 1.0}, 'interestPeriods': {'startDate': {'dateType': 'AdjustableDate', 'date': '2021-03-02'}, 'endDate': {'dateType': 'RelativeAdjustableDate', 'tenor': '10Y', 'referenceDate': 'StartDate'}, 'frequency': 'Annual', 'businessDayAdjustment': {'calendars': [], 'convention': 'ModifiedFollowing'}, 'rollConvention': 'Same'}, 'paymentOffset': {'tenor': '0D', 'businessDayAdjustment': {'calendars': [], 'convention': 'ModifiedFollowing'}, 'referenceDate': 'PeriodEndDate', 'direction': 'Backward'}, 'couponDayCount': 'Dcb_Actual_360', 'accrualDayCount': 'Dcb_Actual_360', 'principal': {'currency': 'EUR', 'amount': 1000000.0}, 'payer': 'Party2', 'receiver': 'Party1'}}], 'pricingPreferences': {'valuationDate': '2021-03-02'}, 'analytics': [{'description': {'instrumentTag': '', 'instrumentDescription': 'Receive EUR Annual +0bp ESTR', 'startDate': '2021-03-02', 'endDate': '2031-03-03', 'tenor': '10Y'}, 'valuation': {'accrued': {'value': 0.0, 'percent': 0.0, 'dealCurrency': {'value': 0.0, 'currency': 'EUR'}, 'reportCurrency': {'value': 0.0, 'currency': 'EUR'}}, 'marketValue': {'value': -18572.358113432358, 'dealCurrency': {'value': -18572.358113432358, 'currency': 'EUR'}, 'reportCurrency': {'value': -18572.358113432358, 'currency': 'EUR'}}, 'cleanMarketValue': {'value': -18572.358113432358, 'dealCurrency': {'value': -18572.358113432358, 'currency': 'EUR'}, 'reportCurrency': {'value': -18572.358113432358, 'currency': 'EUR'}}}, 'risk': {'duration': {'value': 1.0}, 'modifiedDuration': {'value': -6.501023075545686e-05}, 'benchmarkHedgeNotional': {'value': 0.0, 'currency': 'EUR'}, 'annuity': {'value': 0.0, 'dealCurrency': {'value': 0.0, 'currency': 'EUR'}, 'reportCurrency': {'value': 0.0, 'currency': 'EUR'}}, 'dv01': {'value': -0.006501023075543344, 'bp': -6.501023075543344e-05, 'dealCurrency': {'value': -0.006501023075543344, 'currency': 'EUR'}, 'reportCurrency': {'value': -0.006501023075543344, 'currency': 'EUR'}}, 'pv01': {'value': -1020.7340782749961, 'bp': -10.207340782749963, 'dealCurrency': {'value': -1020.7340782749961, 'currency': 'EUR'}, 'reportCurrency': {'value': -1020.7340782749961, 'currency': 'EUR'}}, 'br01': {'value': 0.0, 'dealCurrency': {'value': 0.0, 'currency': 'EUR'}, 'reportCurrency': {'value': 0.0, 'currency': 'EUR'}}}, 'cashflows': [{'paymentType': 'Interest', 'annualRate': {'value': -0.5776998687611, 'unit': 'Percentage'}, 'discountFactor': 1.0058917441089001, 'startDate': '2021-03-02', 'endDate': '2022-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.5857234780388354, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2021-03-03', 'accrualStartDate': '2021-03-02', 'couponRate': {'value': -0.565, 'unit': 'Percentage'}, 'fixingDate': '2021-03-02', 'forwardSource': 'Fixing', 'referenceRate': {'value': -0.565, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-04', 'accrualStartDate': '2021-03-03', 'couponRate': {'value': -0.5638247, 'unit': 'Percentage'}, 'fixingDate': '2021-03-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5638247, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-05', 'accrualStartDate': '2021-03-04', 'couponRate': {'value': -0.56269014, 'unit': 'Percentage'}, 'fixingDate': '2021-03-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56269014, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-08', 'accrualStartDate': '2021-03-05', 'couponRate': {'value': -0.5615541, 'unit': 'Percentage'}, 'fixingDate': '2021-03-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5615541, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-09', 'accrualStartDate': '2021-03-08', 'couponRate': {'value': -0.56157726, 'unit': 'Percentage'}, 'fixingDate': '2021-03-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56157726, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-10', 'accrualStartDate': '2021-03-09', 'couponRate': {'value': -0.56215525, 'unit': 'Percentage'}, 'fixingDate': '2021-03-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56215525, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-11', 'accrualStartDate': '2021-03-10', 'couponRate': {'value': -0.5630757, 'unit': 'Percentage'}, 'fixingDate': '2021-03-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5630757, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-12', 'accrualStartDate': '2021-03-11', 'couponRate': {'value': -0.5642472, 'unit': 'Percentage'}, 'fixingDate': '2021-03-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5642472, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-15', 'accrualStartDate': '2021-03-12', 'couponRate': {'value': -0.56607765, 'unit': 'Percentage'}, 'fixingDate': '2021-03-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56607765, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-16', 'accrualStartDate': '2021-03-15', 'couponRate': {'value': -0.56723964, 'unit': 'Percentage'}, 'fixingDate': '2021-03-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56723964, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-17', 'accrualStartDate': '2021-03-16', 'couponRate': {'value': -0.5674731, 'unit': 'Percentage'}, 'fixingDate': '2021-03-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5674731, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-18', 'accrualStartDate': '2021-03-17', 'couponRate': {'value': -0.5675007, 'unit': 'Percentage'}, 'fixingDate': '2021-03-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5675007, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-19', 'accrualStartDate': '2021-03-18', 'couponRate': {'value': -0.5673635, 'unit': 'Percentage'}, 'fixingDate': '2021-03-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5673635, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-22', 'accrualStartDate': '2021-03-19', 'couponRate': {'value': -0.5671325, 'unit': 'Percentage'}, 'fixingDate': '2021-03-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5671325, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-23', 'accrualStartDate': '2021-03-22', 'couponRate': {'value': -0.5670536, 'unit': 'Percentage'}, 'fixingDate': '2021-03-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5670536, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-24', 'accrualStartDate': '2021-03-23', 'couponRate': {'value': -0.56707686, 'unit': 'Percentage'}, 'fixingDate': '2021-03-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56707686, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-25', 'accrualStartDate': '2021-03-24', 'couponRate': {'value': -0.56714046, 'unit': 'Percentage'}, 'fixingDate': '2021-03-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56714046, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-26', 'accrualStartDate': '2021-03-25', 'couponRate': {'value': -0.5672355, 'unit': 'Percentage'}, 'fixingDate': '2021-03-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5672355, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-29', 'accrualStartDate': '2021-03-26', 'couponRate': {'value': -0.56739277, 'unit': 'Percentage'}, 'fixingDate': '2021-03-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56739277, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-30', 'accrualStartDate': '2021-03-29', 'couponRate': {'value': -0.5675264, 'unit': 'Percentage'}, 'fixingDate': '2021-03-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5675264, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-03-31', 'accrualStartDate': '2021-03-30', 'couponRate': {'value': -0.56756794, 'unit': 'Percentage'}, 'fixingDate': '2021-03-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56756794, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-01', 'accrualStartDate': '2021-03-31', 'couponRate': {'value': -0.5675971, 'unit': 'Percentage'}, 'fixingDate': '2021-03-31', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5675971, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-06', 'accrualStartDate': '2021-04-01', 'couponRate': {'value': -0.56757945, 'unit': 'Percentage'}, 'fixingDate': '2021-04-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56757945, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-07', 'accrualStartDate': '2021-04-06', 'couponRate': {'value': -0.5675136, 'unit': 'Percentage'}, 'fixingDate': '2021-04-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5675136, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-08', 'accrualStartDate': '2021-04-07', 'couponRate': {'value': -0.5674745, 'unit': 'Percentage'}, 'fixingDate': '2021-04-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5674745, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-09', 'accrualStartDate': '2021-04-08', 'couponRate': {'value': -0.5674419, 'unit': 'Percentage'}, 'fixingDate': '2021-04-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5674419, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-12', 'accrualStartDate': '2021-04-09', 'couponRate': {'value': -0.56738925, 'unit': 'Percentage'}, 'fixingDate': '2021-04-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56738925, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-13', 'accrualStartDate': '2021-04-12', 'couponRate': {'value': -0.5673761, 'unit': 'Percentage'}, 'fixingDate': '2021-04-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5673761, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-14', 'accrualStartDate': '2021-04-13', 'couponRate': {'value': -0.5673758, 'unit': 'Percentage'}, 'fixingDate': '2021-04-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5673758, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-15', 'accrualStartDate': '2021-04-14', 'couponRate': {'value': -0.567382, 'unit': 'Percentage'}, 'fixingDate': '2021-04-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.567382, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-16', 'accrualStartDate': '2021-04-15', 'couponRate': {'value': -0.5673947, 'unit': 'Percentage'}, 'fixingDate': '2021-04-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5673947, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-19', 'accrualStartDate': '2021-04-16', 'couponRate': {'value': -0.5674326, 'unit': 'Percentage'}, 'fixingDate': '2021-04-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5674326, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-20', 'accrualStartDate': '2021-04-19', 'couponRate': {'value': -0.56751, 'unit': 'Percentage'}, 'fixingDate': '2021-04-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56751, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-21', 'accrualStartDate': '2021-04-20', 'couponRate': {'value': -0.567555, 'unit': 'Percentage'}, 'fixingDate': '2021-04-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.567555, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-22', 'accrualStartDate': '2021-04-21', 'couponRate': {'value': -0.5676065, 'unit': 'Percentage'}, 'fixingDate': '2021-04-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5676065, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-23', 'accrualStartDate': '2021-04-22', 'couponRate': {'value': -0.56766444, 'unit': 'Percentage'}, 'fixingDate': '2021-04-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56766444, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-26', 'accrualStartDate': '2021-04-23', 'couponRate': {'value': -0.5677929, 'unit': 'Percentage'}, 'fixingDate': '2021-04-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5677929, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-27', 'accrualStartDate': '2021-04-26', 'couponRate': {'value': -0.5679608, 'unit': 'Percentage'}, 'fixingDate': '2021-04-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5679608, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-28', 'accrualStartDate': '2021-04-27', 'couponRate': {'value': -0.5680511, 'unit': 'Percentage'}, 'fixingDate': '2021-04-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5680511, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-29', 'accrualStartDate': '2021-04-28', 'couponRate': {'value': -0.5681478, 'unit': 'Percentage'}, 'fixingDate': '2021-04-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5681478, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-04-30', 'accrualStartDate': '2021-04-29', 'couponRate': {'value': -0.568251, 'unit': 'Percentage'}, 'fixingDate': '2021-04-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.568251, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-03', 'accrualStartDate': '2021-04-30', 'couponRate': {'value': -0.56846994, 'unit': 'Percentage'}, 'fixingDate': '2021-04-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56846994, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-04', 'accrualStartDate': '2021-05-03', 'couponRate': {'value': -0.5687284, 'unit': 'Percentage'}, 'fixingDate': '2021-05-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5687284, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-05', 'accrualStartDate': '2021-05-04', 'couponRate': {'value': -0.5688622, 'unit': 'Percentage'}, 'fixingDate': '2021-05-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5688622, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-06', 'accrualStartDate': '2021-05-05', 'couponRate': {'value': -0.5689943, 'unit': 'Percentage'}, 'fixingDate': '2021-05-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5689943, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-07', 'accrualStartDate': '2021-05-06', 'couponRate': {'value': -0.56912297, 'unit': 'Percentage'}, 'fixingDate': '2021-05-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56912297, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-10', 'accrualStartDate': '2021-05-07', 'couponRate': {'value': -0.56935996, 'unit': 'Percentage'}, 'fixingDate': '2021-05-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56935996, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-11', 'accrualStartDate': '2021-05-10', 'couponRate': {'value': -0.56960356, 'unit': 'Percentage'}, 'fixingDate': '2021-05-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56960356, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-12', 'accrualStartDate': '2021-05-11', 'couponRate': {'value': -0.5697152, 'unit': 'Percentage'}, 'fixingDate': '2021-05-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5697152, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-13', 'accrualStartDate': '2021-05-12', 'couponRate': {'value': -0.5698234, 'unit': 'Percentage'}, 'fixingDate': '2021-05-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5698234, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-14', 'accrualStartDate': '2021-05-13', 'couponRate': {'value': -0.56992817, 'unit': 'Percentage'}, 'fixingDate': '2021-05-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.56992817, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-17', 'accrualStartDate': '2021-05-14', 'couponRate': {'value': -0.5701174, 'unit': 'Percentage'}, 'fixingDate': '2021-05-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5701174, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-18', 'accrualStartDate': '2021-05-17', 'couponRate': {'value': -0.5703133, 'unit': 'Percentage'}, 'fixingDate': '2021-05-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5703133, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-19', 'accrualStartDate': '2021-05-18', 'couponRate': {'value': -0.5704011, 'unit': 'Percentage'}, 'fixingDate': '2021-05-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5704011, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-20', 'accrualStartDate': '2021-05-19', 'couponRate': {'value': -0.5704854, 'unit': 'Percentage'}, 'fixingDate': '2021-05-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5704854, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-21', 'accrualStartDate': '2021-05-20', 'couponRate': {'value': -0.5705663, 'unit': 'Percentage'}, 'fixingDate': '2021-05-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5705663, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-24', 'accrualStartDate': '2021-05-21', 'couponRate': {'value': -0.5707078, 'unit': 'Percentage'}, 'fixingDate': '2021-05-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5707078, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-25', 'accrualStartDate': '2021-05-24', 'couponRate': {'value': -0.570856, 'unit': 'Percentage'}, 'fixingDate': '2021-05-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.570856, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-26', 'accrualStartDate': '2021-05-25', 'couponRate': {'value': -0.5709199, 'unit': 'Percentage'}, 'fixingDate': '2021-05-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5709199, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-27', 'accrualStartDate': '2021-05-26', 'couponRate': {'value': -0.57098037, 'unit': 'Percentage'}, 'fixingDate': '2021-05-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57098037, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-28', 'accrualStartDate': '2021-05-27', 'couponRate': {'value': -0.5710375, 'unit': 'Percentage'}, 'fixingDate': '2021-05-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5710375, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-05-31', 'accrualStartDate': '2021-05-28', 'couponRate': {'value': -0.57113117, 'unit': 'Percentage'}, 'fixingDate': '2021-05-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57113117, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-01', 'accrualStartDate': '2021-05-31', 'couponRate': {'value': -0.5712317, 'unit': 'Percentage'}, 'fixingDate': '2021-05-31', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5712317, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-02', 'accrualStartDate': '2021-06-01', 'couponRate': {'value': -0.5712718, 'unit': 'Percentage'}, 'fixingDate': '2021-06-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5712718, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-03', 'accrualStartDate': '2021-06-02', 'couponRate': {'value': -0.5713084, 'unit': 'Percentage'}, 'fixingDate': '2021-06-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5713084, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-04', 'accrualStartDate': '2021-06-03', 'couponRate': {'value': -0.57134163, 'unit': 'Percentage'}, 'fixingDate': '2021-06-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57134163, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-07', 'accrualStartDate': '2021-06-04', 'couponRate': {'value': -0.5713929, 'unit': 'Percentage'}, 'fixingDate': '2021-06-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5713929, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-08', 'accrualStartDate': '2021-06-07', 'couponRate': {'value': -0.5714619, 'unit': 'Percentage'}, 'fixingDate': '2021-06-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5714619, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-09', 'accrualStartDate': '2021-06-08', 'couponRate': {'value': -0.571492, 'unit': 'Percentage'}, 'fixingDate': '2021-06-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.571492, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-10', 'accrualStartDate': '2021-06-09', 'couponRate': {'value': -0.5715222, 'unit': 'Percentage'}, 'fixingDate': '2021-06-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5715222, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-11', 'accrualStartDate': '2021-06-10', 'couponRate': {'value': -0.5715524, 'unit': 'Percentage'}, 'fixingDate': '2021-06-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5715524, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-14', 'accrualStartDate': '2021-06-11', 'couponRate': {'value': -0.57160395, 'unit': 'Percentage'}, 'fixingDate': '2021-06-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57160395, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-15', 'accrualStartDate': '2021-06-14', 'couponRate': {'value': -0.57167387, 'unit': 'Percentage'}, 'fixingDate': '2021-06-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57167387, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-16', 'accrualStartDate': '2021-06-15', 'couponRate': {'value': -0.57170445, 'unit': 'Percentage'}, 'fixingDate': '2021-06-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57170445, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-17', 'accrualStartDate': '2021-06-16', 'couponRate': {'value': -0.571735, 'unit': 'Percentage'}, 'fixingDate': '2021-06-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.571735, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-18', 'accrualStartDate': '2021-06-17', 'couponRate': {'value': -0.5717657, 'unit': 'Percentage'}, 'fixingDate': '2021-06-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5717657, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-21', 'accrualStartDate': '2021-06-18', 'couponRate': {'value': -0.5718182, 'unit': 'Percentage'}, 'fixingDate': '2021-06-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5718182, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-22', 'accrualStartDate': '2021-06-21', 'couponRate': {'value': -0.571889, 'unit': 'Percentage'}, 'fixingDate': '2021-06-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.571889, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-23', 'accrualStartDate': '2021-06-22', 'couponRate': {'value': -0.57192, 'unit': 'Percentage'}, 'fixingDate': '2021-06-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57192, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-24', 'accrualStartDate': '2021-06-23', 'couponRate': {'value': -0.57195103, 'unit': 'Percentage'}, 'fixingDate': '2021-06-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57195103, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-25', 'accrualStartDate': '2021-06-24', 'couponRate': {'value': -0.57198215, 'unit': 'Percentage'}, 'fixingDate': '2021-06-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57198215, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-28', 'accrualStartDate': '2021-06-25', 'couponRate': {'value': -0.5720355, 'unit': 'Percentage'}, 'fixingDate': '2021-06-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5720355, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-29', 'accrualStartDate': '2021-06-28', 'couponRate': {'value': -0.5721072, 'unit': 'Percentage'}, 'fixingDate': '2021-06-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5721072, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-06-30', 'accrualStartDate': '2021-06-29', 'couponRate': {'value': -0.5721386, 'unit': 'Percentage'}, 'fixingDate': '2021-06-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5721386, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-01', 'accrualStartDate': '2021-06-30', 'couponRate': {'value': -0.57217014, 'unit': 'Percentage'}, 'fixingDate': '2021-06-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57217014, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-02', 'accrualStartDate': '2021-07-01', 'couponRate': {'value': -0.57220167, 'unit': 'Percentage'}, 'fixingDate': '2021-07-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57220167, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-05', 'accrualStartDate': '2021-07-02', 'couponRate': {'value': -0.5722559, 'unit': 'Percentage'}, 'fixingDate': '2021-07-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5722559, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-06', 'accrualStartDate': '2021-07-05', 'couponRate': {'value': -0.57232946, 'unit': 'Percentage'}, 'fixingDate': '2021-07-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57232946, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-07', 'accrualStartDate': '2021-07-06', 'couponRate': {'value': -0.5723669, 'unit': 'Percentage'}, 'fixingDate': '2021-07-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5723669, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-08', 'accrualStartDate': '2021-07-07', 'couponRate': {'value': -0.57241, 'unit': 'Percentage'}, 'fixingDate': '2021-07-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57241, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-09', 'accrualStartDate': '2021-07-08', 'couponRate': {'value': -0.5724587, 'unit': 'Percentage'}, 'fixingDate': '2021-07-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5724587, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-12', 'accrualStartDate': '2021-07-09', 'couponRate': {'value': -0.5725657, 'unit': 'Percentage'}, 'fixingDate': '2021-07-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5725657, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-13', 'accrualStartDate': '2021-07-12', 'couponRate': {'value': -0.5727097, 'unit': 'Percentage'}, 'fixingDate': '2021-07-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5727097, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-14', 'accrualStartDate': '2021-07-13', 'couponRate': {'value': -0.57278645, 'unit': 'Percentage'}, 'fixingDate': '2021-07-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57278645, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-15', 'accrualStartDate': '2021-07-14', 'couponRate': {'value': -0.5728689, 'unit': 'Percentage'}, 'fixingDate': '2021-07-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5728689, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-16', 'accrualStartDate': '2021-07-15', 'couponRate': {'value': -0.5729569, 'unit': 'Percentage'}, 'fixingDate': '2021-07-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5729569, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-19', 'accrualStartDate': '2021-07-16', 'couponRate': {'value': -0.57314265, 'unit': 'Percentage'}, 'fixingDate': '2021-07-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57314265, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-20', 'accrualStartDate': '2021-07-19', 'couponRate': {'value': -0.57336533, 'unit': 'Percentage'}, 'fixingDate': '2021-07-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57336533, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-21', 'accrualStartDate': '2021-07-20', 'couponRate': {'value': -0.5734815, 'unit': 'Percentage'}, 'fixingDate': '2021-07-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5734815, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-22', 'accrualStartDate': '2021-07-21', 'couponRate': {'value': -0.5736033, 'unit': 'Percentage'}, 'fixingDate': '2021-07-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5736033, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-23', 'accrualStartDate': '2021-07-22', 'couponRate': {'value': -0.57373065, 'unit': 'Percentage'}, 'fixingDate': '2021-07-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57373065, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-26', 'accrualStartDate': '2021-07-23', 'couponRate': {'value': -0.573995, 'unit': 'Percentage'}, 'fixingDate': '2021-07-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.573995, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-27', 'accrualStartDate': '2021-07-26', 'couponRate': {'value': -0.5742964, 'unit': 'Percentage'}, 'fixingDate': '2021-07-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5742964, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-28', 'accrualStartDate': '2021-07-27', 'couponRate': {'value': -0.5744519, 'unit': 'Percentage'}, 'fixingDate': '2021-07-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5744519, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-29', 'accrualStartDate': '2021-07-28', 'couponRate': {'value': -0.574613, 'unit': 'Percentage'}, 'fixingDate': '2021-07-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.574613, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-07-30', 'accrualStartDate': '2021-07-29', 'couponRate': {'value': -0.57477975, 'unit': 'Percentage'}, 'fixingDate': '2021-07-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57477975, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-02', 'accrualStartDate': '2021-07-30', 'couponRate': {'value': -0.5751227, 'unit': 'Percentage'}, 'fixingDate': '2021-07-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5751227, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-03', 'accrualStartDate': '2021-08-02', 'couponRate': {'value': -0.57550275, 'unit': 'Percentage'}, 'fixingDate': '2021-08-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57550275, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-04', 'accrualStartDate': '2021-08-03', 'couponRate': {'value': -0.57569754, 'unit': 'Percentage'}, 'fixingDate': '2021-08-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57569754, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-05', 'accrualStartDate': '2021-08-04', 'couponRate': {'value': -0.57589656, 'unit': 'Percentage'}, 'fixingDate': '2021-08-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57589656, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-06', 'accrualStartDate': '2021-08-05', 'couponRate': {'value': -0.57609415, 'unit': 'Percentage'}, 'fixingDate': '2021-08-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57609415, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-09', 'accrualStartDate': '2021-08-06', 'couponRate': {'value': -0.5764708, 'unit': 'Percentage'}, 'fixingDate': '2021-08-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5764708, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-10', 'accrualStartDate': '2021-08-09', 'couponRate': {'value': -0.57685655, 'unit': 'Percentage'}, 'fixingDate': '2021-08-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57685655, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-11', 'accrualStartDate': '2021-08-10', 'couponRate': {'value': -0.57704014, 'unit': 'Percentage'}, 'fixingDate': '2021-08-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57704014, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-12', 'accrualStartDate': '2021-08-11', 'couponRate': {'value': -0.577221, 'unit': 'Percentage'}, 'fixingDate': '2021-08-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.577221, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-13', 'accrualStartDate': '2021-08-12', 'couponRate': {'value': -0.57739896, 'unit': 'Percentage'}, 'fixingDate': '2021-08-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57739896, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-16', 'accrualStartDate': '2021-08-13', 'couponRate': {'value': -0.57773626, 'unit': 'Percentage'}, 'fixingDate': '2021-08-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57773626, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-17', 'accrualStartDate': '2021-08-16', 'couponRate': {'value': -0.57808286, 'unit': 'Percentage'}, 'fixingDate': '2021-08-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57808286, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-18', 'accrualStartDate': '2021-08-17', 'couponRate': {'value': -0.57824683, 'unit': 'Percentage'}, 'fixingDate': '2021-08-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57824683, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-19', 'accrualStartDate': '2021-08-18', 'couponRate': {'value': -0.57840794, 'unit': 'Percentage'}, 'fixingDate': '2021-08-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57840794, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-20', 'accrualStartDate': '2021-08-19', 'couponRate': {'value': -0.5785663, 'unit': 'Percentage'}, 'fixingDate': '2021-08-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5785663, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-23', 'accrualStartDate': '2021-08-20', 'couponRate': {'value': -0.5788644, 'unit': 'Percentage'}, 'fixingDate': '2021-08-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5788644, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-24', 'accrualStartDate': '2021-08-23', 'couponRate': {'value': -0.5791718, 'unit': 'Percentage'}, 'fixingDate': '2021-08-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5791718, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-25', 'accrualStartDate': '2021-08-24', 'couponRate': {'value': -0.57931614, 'unit': 'Percentage'}, 'fixingDate': '2021-08-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57931614, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-26', 'accrualStartDate': '2021-08-25', 'couponRate': {'value': -0.5794577, 'unit': 'Percentage'}, 'fixingDate': '2021-08-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5794577, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-27', 'accrualStartDate': '2021-08-26', 'couponRate': {'value': -0.57959646, 'unit': 'Percentage'}, 'fixingDate': '2021-08-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57959646, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-30', 'accrualStartDate': '2021-08-27', 'couponRate': {'value': -0.57985526, 'unit': 'Percentage'}, 'fixingDate': '2021-08-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.57985526, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-08-31', 'accrualStartDate': '2021-08-30', 'couponRate': {'value': -0.5801235, 'unit': 'Percentage'}, 'fixingDate': '2021-08-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5801235, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-01', 'accrualStartDate': '2021-08-31', 'couponRate': {'value': -0.58024824, 'unit': 'Percentage'}, 'fixingDate': '2021-08-31', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58024824, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-02', 'accrualStartDate': '2021-09-01', 'couponRate': {'value': -0.5803702, 'unit': 'Percentage'}, 'fixingDate': '2021-09-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5803702, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-03', 'accrualStartDate': '2021-09-02', 'couponRate': {'value': -0.58048934, 'unit': 'Percentage'}, 'fixingDate': '2021-09-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58048934, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-06', 'accrualStartDate': '2021-09-03', 'couponRate': {'value': -0.5807089, 'unit': 'Percentage'}, 'fixingDate': '2021-09-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5807089, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-07', 'accrualStartDate': '2021-09-06', 'couponRate': {'value': -0.58093846, 'unit': 'Percentage'}, 'fixingDate': '2021-09-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58093846, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-08', 'accrualStartDate': '2021-09-07', 'couponRate': {'value': -0.5810467, 'unit': 'Percentage'}, 'fixingDate': '2021-09-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5810467, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-09', 'accrualStartDate': '2021-09-08', 'couponRate': {'value': -0.5811552, 'unit': 'Percentage'}, 'fixingDate': '2021-09-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5811552, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-10', 'accrualStartDate': '2021-09-09', 'couponRate': {'value': -0.58126396, 'unit': 'Percentage'}, 'fixingDate': '2021-09-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58126396, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-13', 'accrualStartDate': '2021-09-10', 'couponRate': {'value': -0.58147305, 'unit': 'Percentage'}, 'fixingDate': '2021-09-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58147305, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-14', 'accrualStartDate': '2021-09-13', 'couponRate': {'value': -0.5817018, 'unit': 'Percentage'}, 'fixingDate': '2021-09-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5817018, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-15', 'accrualStartDate': '2021-09-14', 'couponRate': {'value': -0.58181196, 'unit': 'Percentage'}, 'fixingDate': '2021-09-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58181196, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-16', 'accrualStartDate': '2021-09-15', 'couponRate': {'value': -0.5819224, 'unit': 'Percentage'}, 'fixingDate': '2021-09-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5819224, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-17', 'accrualStartDate': '2021-09-16', 'couponRate': {'value': -0.5820331, 'unit': 'Percentage'}, 'fixingDate': '2021-09-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5820331, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-20', 'accrualStartDate': '2021-09-17', 'couponRate': {'value': -0.58224595, 'unit': 'Percentage'}, 'fixingDate': '2021-09-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58224595, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-21', 'accrualStartDate': '2021-09-20', 'couponRate': {'value': -0.5824786, 'unit': 'Percentage'}, 'fixingDate': '2021-09-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5824786, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-22', 'accrualStartDate': '2021-09-21', 'couponRate': {'value': -0.58259064, 'unit': 'Percentage'}, 'fixingDate': '2021-09-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58259064, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-23', 'accrualStartDate': '2021-09-22', 'couponRate': {'value': -0.58270293, 'unit': 'Percentage'}, 'fixingDate': '2021-09-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58270293, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-24', 'accrualStartDate': '2021-09-23', 'couponRate': {'value': -0.5828155, 'unit': 'Percentage'}, 'fixingDate': '2021-09-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5828155, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-27', 'accrualStartDate': '2021-09-24', 'couponRate': {'value': -0.58303225, 'unit': 'Percentage'}, 'fixingDate': '2021-09-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58303225, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-28', 'accrualStartDate': '2021-09-27', 'couponRate': {'value': -0.5832687, 'unit': 'Percentage'}, 'fixingDate': '2021-09-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5832687, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-29', 'accrualStartDate': '2021-09-28', 'couponRate': {'value': -0.58338267, 'unit': 'Percentage'}, 'fixingDate': '2021-09-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58338267, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-09-30', 'accrualStartDate': '2021-09-29', 'couponRate': {'value': -0.5834969, 'unit': 'Percentage'}, 'fixingDate': '2021-09-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5834969, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-01', 'accrualStartDate': '2021-09-30', 'couponRate': {'value': -0.5836114, 'unit': 'Percentage'}, 'fixingDate': '2021-09-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5836114, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-04', 'accrualStartDate': '2021-10-01', 'couponRate': {'value': -0.58383185, 'unit': 'Percentage'}, 'fixingDate': '2021-10-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58383185, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-05', 'accrualStartDate': '2021-10-04', 'couponRate': {'value': -0.58407223, 'unit': 'Percentage'}, 'fixingDate': '2021-10-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58407223, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-06', 'accrualStartDate': '2021-10-05', 'couponRate': {'value': -0.58418834, 'unit': 'Percentage'}, 'fixingDate': '2021-10-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58418834, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-07', 'accrualStartDate': '2021-10-06', 'couponRate': {'value': -0.584305, 'unit': 'Percentage'}, 'fixingDate': '2021-10-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.584305, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-08', 'accrualStartDate': '2021-10-07', 'couponRate': {'value': -0.5844222, 'unit': 'Percentage'}, 'fixingDate': '2021-10-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5844222, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-11', 'accrualStartDate': '2021-10-08', 'couponRate': {'value': -0.58464867, 'unit': 'Percentage'}, 'fixingDate': '2021-10-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58464867, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-12', 'accrualStartDate': '2021-10-11', 'couponRate': {'value': -0.58489597, 'unit': 'Percentage'}, 'fixingDate': '2021-10-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58489597, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-13', 'accrualStartDate': '2021-10-12', 'couponRate': {'value': -0.5850157, 'unit': 'Percentage'}, 'fixingDate': '2021-10-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5850157, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-14', 'accrualStartDate': '2021-10-13', 'couponRate': {'value': -0.585136, 'unit': 'Percentage'}, 'fixingDate': '2021-10-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.585136, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-15', 'accrualStartDate': '2021-10-14', 'couponRate': {'value': -0.58525676, 'unit': 'Percentage'}, 'fixingDate': '2021-10-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58525676, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-18', 'accrualStartDate': '2021-10-15', 'couponRate': {'value': -0.5854905, 'unit': 'Percentage'}, 'fixingDate': '2021-10-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5854905, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-19', 'accrualStartDate': '2021-10-18', 'couponRate': {'value': -0.5857451, 'unit': 'Percentage'}, 'fixingDate': '2021-10-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5857451, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-20', 'accrualStartDate': '2021-10-19', 'couponRate': {'value': -0.5858685, 'unit': 'Percentage'}, 'fixingDate': '2021-10-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5858685, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-21', 'accrualStartDate': '2021-10-20', 'couponRate': {'value': -0.58599234, 'unit': 'Percentage'}, 'fixingDate': '2021-10-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58599234, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-22', 'accrualStartDate': '2021-10-21', 'couponRate': {'value': -0.58611673, 'unit': 'Percentage'}, 'fixingDate': '2021-10-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58611673, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-25', 'accrualStartDate': '2021-10-22', 'couponRate': {'value': -0.5863578, 'unit': 'Percentage'}, 'fixingDate': '2021-10-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5863578, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-26', 'accrualStartDate': '2021-10-25', 'couponRate': {'value': -0.58661956, 'unit': 'Percentage'}, 'fixingDate': '2021-10-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58661956, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-27', 'accrualStartDate': '2021-10-26', 'couponRate': {'value': -0.5867466, 'unit': 'Percentage'}, 'fixingDate': '2021-10-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5867466, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-28', 'accrualStartDate': '2021-10-27', 'couponRate': {'value': -0.58687407, 'unit': 'Percentage'}, 'fixingDate': '2021-10-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58687407, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-10-29', 'accrualStartDate': '2021-10-28', 'couponRate': {'value': -0.5870021, 'unit': 'Percentage'}, 'fixingDate': '2021-10-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5870021, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-01', 'accrualStartDate': '2021-10-29', 'couponRate': {'value': -0.58725035, 'unit': 'Percentage'}, 'fixingDate': '2021-10-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58725035, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-02', 'accrualStartDate': '2021-11-01', 'couponRate': {'value': -0.5875194, 'unit': 'Percentage'}, 'fixingDate': '2021-11-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5875194, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-03', 'accrualStartDate': '2021-11-02', 'couponRate': {'value': -0.58765006, 'unit': 'Percentage'}, 'fixingDate': '2021-11-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58765006, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-04', 'accrualStartDate': '2021-11-03', 'couponRate': {'value': -0.5877812, 'unit': 'Percentage'}, 'fixingDate': '2021-11-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5877812, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-05', 'accrualStartDate': '2021-11-04', 'couponRate': {'value': -0.5879125, 'unit': 'Percentage'}, 'fixingDate': '2021-11-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5879125, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-08', 'accrualStartDate': '2021-11-05', 'couponRate': {'value': -0.58816105, 'unit': 'Percentage'}, 'fixingDate': '2021-11-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58816105, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-09', 'accrualStartDate': '2021-11-08', 'couponRate': {'value': -0.58842367, 'unit': 'Percentage'}, 'fixingDate': '2021-11-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58842367, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-10', 'accrualStartDate': '2021-11-09', 'couponRate': {'value': -0.5885476, 'unit': 'Percentage'}, 'fixingDate': '2021-11-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5885476, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-11', 'accrualStartDate': '2021-11-10', 'couponRate': {'value': -0.58866996, 'unit': 'Percentage'}, 'fixingDate': '2021-11-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58866996, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-12', 'accrualStartDate': '2021-11-11', 'couponRate': {'value': -0.5887908, 'unit': 'Percentage'}, 'fixingDate': '2021-11-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5887908, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-15', 'accrualStartDate': '2021-11-12', 'couponRate': {'value': -0.5890177, 'unit': 'Percentage'}, 'fixingDate': '2021-11-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5890177, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-16', 'accrualStartDate': '2021-11-15', 'couponRate': {'value': -0.5892587, 'unit': 'Percentage'}, 'fixingDate': '2021-11-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5892587, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-17', 'accrualStartDate': '2021-11-16', 'couponRate': {'value': -0.5893718, 'unit': 'Percentage'}, 'fixingDate': '2021-11-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5893718, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-18', 'accrualStartDate': '2021-11-17', 'couponRate': {'value': -0.5894834, 'unit': 'Percentage'}, 'fixingDate': '2021-11-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5894834, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-19', 'accrualStartDate': '2021-11-18', 'couponRate': {'value': -0.58959335, 'unit': 'Percentage'}, 'fixingDate': '2021-11-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58959335, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-22', 'accrualStartDate': '2021-11-19', 'couponRate': {'value': -0.5897986, 'unit': 'Percentage'}, 'fixingDate': '2021-11-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5897986, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-23', 'accrualStartDate': '2021-11-22', 'couponRate': {'value': -0.59001803, 'unit': 'Percentage'}, 'fixingDate': '2021-11-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59001803, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-24', 'accrualStartDate': '2021-11-23', 'couponRate': {'value': -0.5901203, 'unit': 'Percentage'}, 'fixingDate': '2021-11-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5901203, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-25', 'accrualStartDate': '2021-11-24', 'couponRate': {'value': -0.5902211, 'unit': 'Percentage'}, 'fixingDate': '2021-11-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5902211, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-26', 'accrualStartDate': '2021-11-25', 'couponRate': {'value': -0.5903203, 'unit': 'Percentage'}, 'fixingDate': '2021-11-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5903203, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-29', 'accrualStartDate': '2021-11-26', 'couponRate': {'value': -0.5905039, 'unit': 'Percentage'}, 'fixingDate': '2021-11-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5905039, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-11-30', 'accrualStartDate': '2021-11-29', 'couponRate': {'value': -0.5907017, 'unit': 'Percentage'}, 'fixingDate': '2021-11-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5907017, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-01', 'accrualStartDate': '2021-11-30', 'couponRate': {'value': -0.5907932, 'unit': 'Percentage'}, 'fixingDate': '2021-11-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5907932, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-02', 'accrualStartDate': '2021-12-01', 'couponRate': {'value': -0.59088314, 'unit': 'Percentage'}, 'fixingDate': '2021-12-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59088314, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-03', 'accrualStartDate': '2021-12-02', 'couponRate': {'value': -0.5909716, 'unit': 'Percentage'}, 'fixingDate': '2021-12-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5909716, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-06', 'accrualStartDate': '2021-12-03', 'couponRate': {'value': -0.59113353, 'unit': 'Percentage'}, 'fixingDate': '2021-12-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59113353, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-07', 'accrualStartDate': '2021-12-06', 'couponRate': {'value': -0.5913089, 'unit': 'Percentage'}, 'fixingDate': '2021-12-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5913089, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-08', 'accrualStartDate': '2021-12-07', 'couponRate': {'value': -0.5913841, 'unit': 'Percentage'}, 'fixingDate': '2021-12-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5913841, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-09', 'accrualStartDate': '2021-12-08', 'couponRate': {'value': -0.59145236, 'unit': 'Percentage'}, 'fixingDate': '2021-12-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59145236, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-10', 'accrualStartDate': '2021-12-09', 'couponRate': {'value': -0.59151363, 'unit': 'Percentage'}, 'fixingDate': '2021-12-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59151363, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-13', 'accrualStartDate': '2021-12-10', 'couponRate': {'value': -0.5916031, 'unit': 'Percentage'}, 'fixingDate': '2021-12-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5916031, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-14', 'accrualStartDate': '2021-12-13', 'couponRate': {'value': -0.5916887, 'unit': 'Percentage'}, 'fixingDate': '2021-12-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5916887, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-15', 'accrualStartDate': '2021-12-14', 'couponRate': {'value': -0.591715, 'unit': 'Percentage'}, 'fixingDate': '2021-12-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.591715, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-16', 'accrualStartDate': '2021-12-15', 'couponRate': {'value': -0.59173423, 'unit': 'Percentage'}, 'fixingDate': '2021-12-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59173423, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-17', 'accrualStartDate': '2021-12-16', 'couponRate': {'value': -0.59174657, 'unit': 'Percentage'}, 'fixingDate': '2021-12-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59174657, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-20', 'accrualStartDate': '2021-12-17', 'couponRate': {'value': -0.5917381, 'unit': 'Percentage'}, 'fixingDate': '2021-12-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5917381, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-21', 'accrualStartDate': '2021-12-20', 'couponRate': {'value': -0.5917258, 'unit': 'Percentage'}, 'fixingDate': '2021-12-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5917258, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-22', 'accrualStartDate': '2021-12-21', 'couponRate': {'value': -0.5917032, 'unit': 'Percentage'}, 'fixingDate': '2021-12-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5917032, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-23', 'accrualStartDate': '2021-12-22', 'couponRate': {'value': -0.59167355, 'unit': 'Percentage'}, 'fixingDate': '2021-12-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59167355, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-24', 'accrualStartDate': '2021-12-23', 'couponRate': {'value': -0.59163696, 'unit': 'Percentage'}, 'fixingDate': '2021-12-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59163696, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-27', 'accrualStartDate': '2021-12-24', 'couponRate': {'value': -0.5915307, 'unit': 'Percentage'}, 'fixingDate': '2021-12-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5915307, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-28', 'accrualStartDate': '2021-12-27', 'couponRate': {'value': -0.59142053, 'unit': 'Percentage'}, 'fixingDate': '2021-12-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59142053, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-29', 'accrualStartDate': '2021-12-28', 'couponRate': {'value': -0.591349, 'unit': 'Percentage'}, 'fixingDate': '2021-12-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.591349, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-30', 'accrualStartDate': '2021-12-29', 'couponRate': {'value': -0.59127045, 'unit': 'Percentage'}, 'fixingDate': '2021-12-29', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59127045, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2021-12-31', 'accrualStartDate': '2021-12-30', 'couponRate': {'value': -0.5911849, 'unit': 'Percentage'}, 'fixingDate': '2021-12-30', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5911849, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-03', 'accrualStartDate': '2021-12-31', 'couponRate': {'value': -0.5909808, 'unit': 'Percentage'}, 'fixingDate': '2021-12-31', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5909808, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-04', 'accrualStartDate': '2022-01-03', 'couponRate': {'value': -0.5907729, 'unit': 'Percentage'}, 'fixingDate': '2022-01-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5907729, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-05', 'accrualStartDate': '2022-01-04', 'couponRate': {'value': -0.5906539, 'unit': 'Percentage'}, 'fixingDate': '2022-01-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5906539, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-06', 'accrualStartDate': '2022-01-05', 'couponRate': {'value': -0.5905351, 'unit': 'Percentage'}, 'fixingDate': '2022-01-05', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5905351, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-07', 'accrualStartDate': '2022-01-06', 'couponRate': {'value': -0.590418, 'unit': 'Percentage'}, 'fixingDate': '2022-01-06', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.590418, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-10', 'accrualStartDate': '2022-01-07', 'couponRate': {'value': -0.5901796, 'unit': 'Percentage'}, 'fixingDate': '2022-01-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5901796, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-11', 'accrualStartDate': '2022-01-10', 'couponRate': {'value': -0.5899662, 'unit': 'Percentage'}, 'fixingDate': '2022-01-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5899662, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-12', 'accrualStartDate': '2022-01-11', 'couponRate': {'value': -0.5898574, 'unit': 'Percentage'}, 'fixingDate': '2022-01-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5898574, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-13', 'accrualStartDate': '2022-01-12', 'couponRate': {'value': -0.58975023, 'unit': 'Percentage'}, 'fixingDate': '2022-01-12', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58975023, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-14', 'accrualStartDate': '2022-01-13', 'couponRate': {'value': -0.5896448, 'unit': 'Percentage'}, 'fixingDate': '2022-01-13', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5896448, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-17', 'accrualStartDate': '2022-01-14', 'couponRate': {'value': -0.58942974, 'unit': 'Percentage'}, 'fixingDate': '2022-01-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58942974, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-18', 'accrualStartDate': '2022-01-17', 'couponRate': {'value': -0.5892396, 'unit': 'Percentage'}, 'fixingDate': '2022-01-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5892396, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-19', 'accrualStartDate': '2022-01-18', 'couponRate': {'value': -0.58914244, 'unit': 'Percentage'}, 'fixingDate': '2022-01-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58914244, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-20', 'accrualStartDate': '2022-01-19', 'couponRate': {'value': -0.58904696, 'unit': 'Percentage'}, 'fixingDate': '2022-01-19', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58904696, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-21', 'accrualStartDate': '2022-01-20', 'couponRate': {'value': -0.58895314, 'unit': 'Percentage'}, 'fixingDate': '2022-01-20', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58895314, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-24', 'accrualStartDate': '2022-01-21', 'couponRate': {'value': -0.58876145, 'unit': 'Percentage'}, 'fixingDate': '2022-01-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58876145, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-25', 'accrualStartDate': '2022-01-24', 'couponRate': {'value': -0.58859456, 'unit': 'Percentage'}, 'fixingDate': '2022-01-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58859456, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-26', 'accrualStartDate': '2022-01-25', 'couponRate': {'value': -0.5885091, 'unit': 'Percentage'}, 'fixingDate': '2022-01-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5885091, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-27', 'accrualStartDate': '2022-01-26', 'couponRate': {'value': -0.5884253, 'unit': 'Percentage'}, 'fixingDate': '2022-01-26', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5884253, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-28', 'accrualStartDate': '2022-01-27', 'couponRate': {'value': -0.5883431, 'unit': 'Percentage'}, 'fixingDate': '2022-01-27', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5883431, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-01-31', 'accrualStartDate': '2022-01-28', 'couponRate': {'value': -0.5881747, 'unit': 'Percentage'}, 'fixingDate': '2022-01-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5881747, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-01', 'accrualStartDate': '2022-01-31', 'couponRate': {'value': -0.58803105, 'unit': 'Percentage'}, 'fixingDate': '2022-01-31', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58803105, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-02', 'accrualStartDate': '2022-02-01', 'couponRate': {'value': -0.58795726, 'unit': 'Percentage'}, 'fixingDate': '2022-02-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58795726, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-03', 'accrualStartDate': '2022-02-02', 'couponRate': {'value': -0.5878851, 'unit': 'Percentage'}, 'fixingDate': '2022-02-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5878851, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-04', 'accrualStartDate': '2022-02-03', 'couponRate': {'value': -0.5878145, 'unit': 'Percentage'}, 'fixingDate': '2022-02-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5878145, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-07', 'accrualStartDate': '2022-02-04', 'couponRate': {'value': -0.58769184, 'unit': 'Percentage'}, 'fixingDate': '2022-02-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58769184, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-08', 'accrualStartDate': '2022-02-07', 'couponRate': {'value': -0.58764124, 'unit': 'Percentage'}, 'fixingDate': '2022-02-07', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58764124, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-09', 'accrualStartDate': '2022-02-08', 'couponRate': {'value': -0.5876388, 'unit': 'Percentage'}, 'fixingDate': '2022-02-08', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5876388, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-10', 'accrualStartDate': '2022-02-09', 'couponRate': {'value': -0.587653, 'unit': 'Percentage'}, 'fixingDate': '2022-02-09', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.587653, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-11', 'accrualStartDate': '2022-02-10', 'couponRate': {'value': -0.58768374, 'unit': 'Percentage'}, 'fixingDate': '2022-02-10', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58768374, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-14', 'accrualStartDate': '2022-02-11', 'couponRate': {'value': -0.587791, 'unit': 'Percentage'}, 'fixingDate': '2022-02-11', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.587791, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-15', 'accrualStartDate': '2022-02-14', 'couponRate': {'value': -0.5879729, 'unit': 'Percentage'}, 'fixingDate': '2022-02-14', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5879729, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-16', 'accrualStartDate': '2022-02-15', 'couponRate': {'value': -0.5880866, 'unit': 'Percentage'}, 'fixingDate': '2022-02-15', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5880866, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-17', 'accrualStartDate': '2022-02-16', 'couponRate': {'value': -0.588217, 'unit': 'Percentage'}, 'fixingDate': '2022-02-16', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.588217, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-18', 'accrualStartDate': '2022-02-17', 'couponRate': {'value': -0.58836395, 'unit': 'Percentage'}, 'fixingDate': '2022-02-17', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58836395, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-21', 'accrualStartDate': '2022-02-18', 'couponRate': {'value': -0.5887036, 'unit': 'Percentage'}, 'fixingDate': '2022-02-18', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5887036, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-22', 'accrualStartDate': '2022-02-21', 'couponRate': {'value': -0.5891177, 'unit': 'Percentage'}, 'fixingDate': '2022-02-21', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5891177, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-23', 'accrualStartDate': '2022-02-22', 'couponRate': {'value': -0.58934766, 'unit': 'Percentage'}, 'fixingDate': '2022-02-22', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.58934766, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-24', 'accrualStartDate': '2022-02-23', 'couponRate': {'value': -0.5895941, 'unit': 'Percentage'}, 'fixingDate': '2022-02-23', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5895941, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-25', 'accrualStartDate': '2022-02-24', 'couponRate': {'value': -0.5898572, 'unit': 'Percentage'}, 'fixingDate': '2022-02-24', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5898572, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-02-28', 'accrualStartDate': '2022-02-25', 'couponRate': {'value': -0.590429, 'unit': 'Percentage'}, 'fixingDate': '2022-02-25', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.590429, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-03-01', 'accrualStartDate': '2022-02-28', 'couponRate': {'value': -0.5910755, 'unit': 'Percentage'}, 'fixingDate': '2022-02-28', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5910755, 'unit': 'Percentage'}, 'spreadBp': 0.0}, {'accrualEndDate': '2022-03-02', 'accrualStartDate': '2022-03-01', 'couponRate': {'value': -0.5914215, 'unit': 'Percentage'}, 'fixingDate': '2022-03-01', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5914215, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2022-03-02'}, 'amount': {'value': -5857.234780494486, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.5929854034229001, 'unit': 'Percentage'}, 'discountFactor': 1.0119759592460968, 'startDate': '2022-03-02', 'endDate': '2023-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.5934726969362814, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2023-03-02', 'accrualStartDate': '2022-03-02', 'couponRate': {'value': -0.5929854, 'unit': 'Percentage'}, 'fixingDate': '2022-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.5929854, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2023-03-02'}, 'amount': {'value': -6012.213118037736, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.5900714270630001, 'unit': 'Percentage'}, 'discountFactor': 1.0181170798500445, 'startDate': '2023-03-02', 'endDate': '2024-03-04', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.595625297376734, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2024-03-04', 'accrualStartDate': '2023-03-02', 'couponRate': {'value': -0.59007144, 'unit': 'Percentage'}, 'fixingDate': '2023-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.59007144, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2024-03-04'}, 'amount': {'value': -6031.841254421778, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.3825091872524, 'unit': 'Percentage'}, 'discountFactor': 1.0220700306369428, 'startDate': '2024-03-04', 'endDate': '2025-03-03', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.54389228911631, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2025-03-03', 'accrualStartDate': '2024-03-04', 'couponRate': {'value': -0.3825092, 'unit': 'Percentage'}, 'fixingDate': '2024-03-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.3825092, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2025-03-03'}, 'amount': {'value': -3867.5928933298223, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.31769169686550003, 'unit': 'Percentage'}, 'discountFactor': 1.0253637204327237, 'startDate': '2025-03-03', 'endDate': '2026-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.4996953251847902, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2026-03-02', 'accrualStartDate': '2025-03-03', 'couponRate': {'value': -0.31769168, 'unit': 'Percentage'}, 'fixingDate': '2025-03-03', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.31769168, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2026-03-02'}, 'amount': {'value': -3212.2160460845, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.1412312105185, 'unit': 'Percentage'}, 'discountFactor': 1.0268340724314076, 'startDate': '2026-03-02', 'endDate': '2027-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.44036673946632465, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2027-03-02', 'accrualStartDate': '2026-03-02', 'couponRate': {'value': -0.14123121, 'unit': 'Percentage'}, 'fixingDate': '2026-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.14123121, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2027-03-02'}, 'amount': {'value': -1431.9275510903472, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': -0.0031376447609000003, 'unit': 'Percentage'}, 'discountFactor': 1.026866828855218, 'startDate': '2027-03-02', 'endDate': '2028-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.37803012430979166, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2028-03-02', 'accrualStartDate': '2027-03-02', 'couponRate': {'value': -0.0031376448, 'unit': 'Percentage'}, 'fixingDate': '2027-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': -0.0031376448, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2028-03-02'}, 'amount': {'value': -31.899388402483332, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': 0.1386636808419, 'unit': 'Percentage'}, 'discountFactor': 1.0254251880409235, 'startDate': '2028-03-02', 'endDate': '2029-03-02', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.3133498336461038, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2029-03-02', 'accrualStartDate': '2028-03-02', 'couponRate': {'value': 0.13866368, 'unit': 'Percentage'}, 'fixingDate': '2028-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': 0.13866368, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2029-03-02'}, 'amount': {'value': 1405.895652980375, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': 0.2503159110993, 'unit': 'Percentage'}, 'discountFactor': 1.0228151360055724, 'startDate': '2029-03-02', 'endDate': '2030-03-04', 'remainingNotional': 1000000.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.2501869192443773, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2030-03-04', 'accrualStartDate': '2029-03-02', 'couponRate': {'value': 0.2503159, 'unit': 'Percentage'}, 'fixingDate': '2029-03-02', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': 0.2503159, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2030-03-04'}, 'amount': {'value': 2551.8316492623085, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}, {'paymentType': 'Interest', 'annualRate': {'value': 0.4119642484185, 'unit': 'Percentage'}, 'discountFactor': 1.0185723581130723, 'startDate': '2030-03-04', 'endDate': '2031-03-03', 'remainingNotional': 0.0, 'interestRateType': 'FloatingRate', 'zeroRate': {'value': -0.18380045671523293, 'unit': 'Percentage'}, 'indexFixings': [{'accrualEndDate': '2031-03-03', 'accrualStartDate': '2030-03-04', 'couponRate': {'value': 0.41196424, 'unit': 'Percentage'}, 'fixingDate': '2030-03-04', 'forwardSource': 'ZcCurve', 'referenceRate': {'value': 0.41196424, 'unit': 'Percentage'}, 'spreadBp': 0.0}], 'date': {'dateType': 'AdjustableDate', 'date': '2031-03-03'}, 'amount': {'value': 4165.416289564833, 'currency': 'EUR'}, 'payer': 'Party2', 'receiver': 'Party1', 'occurrence': 'Projected'}]}]}

    """

    try:
        logger.info("Calling value")

        response = Client().loans_resource.value(
            fields=fields,
            definitions=definitions,
            pricing_preferences=pricing_preferences,
            market_data=market_data,
            return_market_data=return_market_data,
        )

        output = response.data
        logger.info("Called value")

        return output
    except Exception as err:
        logger.error("Error value.")
        check_exception_and_raise(err, logger)
